module Text.Numerals.Languages.EnglishSpec (
    spec
  ) where

import Data.Text(Text)
import Data.Time.LocalTime(TimeOfDay(TimeOfDay))

import Test.Hspec(Spec)
import Text.Numerals.Languages.English(english)
import Text.Numerals.LanguageTest(testLanguage)

spec :: Spec
spec = testLanguage "English" english (cardinals <> minusCardinals) ordinals shortOrdinals clockTime

cardinals :: [(Integer, Text)]
cardinals = [
    (0, "zero")
  , (1, "one")
  , (2, "two")
  , (3, "three")
  , (4, "four")
  , (5, "five")
  , (6, "six")
  , (7, "seven")
  , (8, "eight")
  , (9, "nine")
  , (10, "ten")
  , (11, "eleven")
  , (12, "twelve")
  , (13, "thirteen")
  , (14, "fourteen")
  , (15, "fifteen")
  , (16, "sixteen")
  , (17, "seventeen")
  , (18, "eighteen")
  , (19, "nineteen")
  , (20, "twenty")
  , (21, "twenty-one")
  , (22, "twenty-two")
  , (23, "twenty-three")
  , (24, "twenty-four")
  , (25, "twenty-five")
  , (26, "twenty-six")
  , (27, "twenty-seven")
  , (28, "twenty-eight")
  , (29, "twenty-nine")
  , (30, "thirty")
  , (31, "thirty-one")
  , (32, "thirty-two")
  , (33, "thirty-three")
  , (34, "thirty-four")
  , (35, "thirty-five")
  , (36, "thirty-six")
  , (37, "thirty-seven")
  , (38, "thirty-eight")
  , (39, "thirty-nine")
  , (40, "forty")
  , (41, "forty-one")
  , (42, "forty-two")
  , (43, "forty-three")
  , (44, "forty-four")
  , (45, "forty-five")
  , (46, "forty-six")
  , (47, "forty-seven")
  , (48, "forty-eight")
  , (49, "forty-nine")
  , (50, "fifty")
  , (51, "fifty-one")
  , (52, "fifty-two")
  , (53, "fifty-three")
  , (54, "fifty-four")
  , (55, "fifty-five")
  , (56, "fifty-six")
  , (57, "fifty-seven")
  , (58, "fifty-eight")
  , (59, "fifty-nine")
  , (60, "sixty")
  , (61, "sixty-one")
  , (62, "sixty-two")
  , (63, "sixty-three")
  , (64, "sixty-four")
  , (65, "sixty-five")
  , (66, "sixty-six")
  , (67, "sixty-seven")
  , (68, "sixty-eight")
  , (69, "sixty-nine")
  , (70, "seventy")
  , (71, "seventy-one")
  , (72, "seventy-two")
  , (73, "seventy-three")
  , (74, "seventy-four")
  , (75, "seventy-five")
  , (76, "seventy-six")
  , (77, "seventy-seven")
  , (78, "seventy-eight")
  , (79, "seventy-nine")
  , (80, "eighty")
  , (81, "eighty-one")
  , (82, "eighty-two")
  , (83, "eighty-three")
  , (84, "eighty-four")
  , (85, "eighty-five")
  , (86, "eighty-six")
  , (87, "eighty-seven")
  , (88, "eighty-eight")
  , (89, "eighty-nine")
  , (90, "ninety")
  , (91, "ninety-one")
  , (92, "ninety-two")
  , (93, "ninety-three")
  , (94, "ninety-four")
  , (95, "ninety-five")
  , (96, "ninety-six")
  , (97, "ninety-seven")
  , (98, "ninety-eight")
  , (99, "ninety-nine")
  , (100, "one hundred")
  , (101, "one hundred and one")
  , (102, "one hundred and two")
  , (103, "one hundred and three")
  , (104, "one hundred and four")
  , (105, "one hundred and five")
  , (106, "one hundred and six")
  , (107, "one hundred and seven")
  , (108, "one hundred and eight")
  , (109, "one hundred and nine")
  , (110, "one hundred and ten")
  , (111, "one hundred and eleven")
  , (112, "one hundred and twelve")
  , (113, "one hundred and thirteen")
  , (114, "one hundred and fourteen")
  , (115, "one hundred and fifteen")
  , (116, "one hundred and sixteen")
  , (117, "one hundred and seventeen")
  , (118, "one hundred and eighteen")
  , (119, "one hundred and nineteen")
  , (120, "one hundred and twenty")
  , (121, "one hundred and twenty-one")
  , (122, "one hundred and twenty-two")
  , (123, "one hundred and twenty-three")
  , (124, "one hundred and twenty-four")
  , (125, "one hundred and twenty-five")
  , (126, "one hundred and twenty-six")
  , (127, "one hundred and twenty-seven")
  , (128, "one hundred and twenty-eight")
  , (129, "one hundred and twenty-nine")
  , (130, "one hundred and thirty")
  , (131, "one hundred and thirty-one")
  , (132, "one hundred and thirty-two")
  , (133, "one hundred and thirty-three")
  , (134, "one hundred and thirty-four")
  , (135, "one hundred and thirty-five")
  , (136, "one hundred and thirty-six")
  , (137, "one hundred and thirty-seven")
  , (138, "one hundred and thirty-eight")
  , (139, "one hundred and thirty-nine")
  , (140, "one hundred and forty")
  , (141, "one hundred and forty-one")
  , (142, "one hundred and forty-two")
  , (143, "one hundred and forty-three")
  , (144, "one hundred and forty-four")
  , (145, "one hundred and forty-five")
  , (146, "one hundred and forty-six")
  , (147, "one hundred and forty-seven")
  , (148, "one hundred and forty-eight")
  , (149, "one hundred and forty-nine")
  , (150, "one hundred and fifty")
  , (151, "one hundred and fifty-one")
  , (152, "one hundred and fifty-two")
  , (153, "one hundred and fifty-three")
  , (154, "one hundred and fifty-four")
  , (155, "one hundred and fifty-five")
  , (156, "one hundred and fifty-six")
  , (157, "one hundred and fifty-seven")
  , (158, "one hundred and fifty-eight")
  , (159, "one hundred and fifty-nine")
  , (160, "one hundred and sixty")
  , (161, "one hundred and sixty-one")
  , (162, "one hundred and sixty-two")
  , (163, "one hundred and sixty-three")
  , (164, "one hundred and sixty-four")
  , (165, "one hundred and sixty-five")
  , (166, "one hundred and sixty-six")
  , (167, "one hundred and sixty-seven")
  , (168, "one hundred and sixty-eight")
  , (169, "one hundred and sixty-nine")
  , (170, "one hundred and seventy")
  , (171, "one hundred and seventy-one")
  , (172, "one hundred and seventy-two")
  , (173, "one hundred and seventy-three")
  , (174, "one hundred and seventy-four")
  , (175, "one hundred and seventy-five")
  , (176, "one hundred and seventy-six")
  , (177, "one hundred and seventy-seven")
  , (178, "one hundred and seventy-eight")
  , (179, "one hundred and seventy-nine")
  , (180, "one hundred and eighty")
  , (181, "one hundred and eighty-one")
  , (182, "one hundred and eighty-two")
  , (183, "one hundred and eighty-three")
  , (184, "one hundred and eighty-four")
  , (185, "one hundred and eighty-five")
  , (186, "one hundred and eighty-six")
  , (187, "one hundred and eighty-seven")
  , (188, "one hundred and eighty-eight")
  , (189, "one hundred and eighty-nine")
  , (190, "one hundred and ninety")
  , (191, "one hundred and ninety-one")
  , (192, "one hundred and ninety-two")
  , (193, "one hundred and ninety-three")
  , (194, "one hundred and ninety-four")
  , (195, "one hundred and ninety-five")
  , (196, "one hundred and ninety-six")
  , (197, "one hundred and ninety-seven")
  , (198, "one hundred and ninety-eight")
  , (199, "one hundred and ninety-nine")
  , (200, "two hundred")
  , (233, "two hundred and thirty-three")
  , (377, "three hundred and seventy-seven")
  , (610, "six hundred and ten")
  , (987, "nine hundred and eighty-seven")
  , (1597, "one thousand, five hundred and ninety-seven")
  , (2584, "two thousand, five hundred and eighty-four")
  , (4181, "four thousand, one hundred and eighty-one")
  , (6765, "six thousand, seven hundred and sixty-five")
  , (10946, "ten thousand, nine hundred and forty-six")
  , (17711, "seventeen thousand, seven hundred and eleven")
  , (28657, "twenty-eight thousand, six hundred and fifty-seven")
  , (46368, "forty-six thousand, three hundred and sixty-eight")
  , (75025, "seventy-five thousand and twenty-five")
  , (121393, "one hundred and twenty-one thousand, three hundred and ninety-three")
  , (196418, "one hundred and ninety-six thousand, four hundred and eighteen")
  , (317811, "three hundred and seventeen thousand, eight hundred and eleven")
  , (514229, "five hundred and fourteen thousand, two hundred and twenty-nine")
  , (832040, "eight hundred and thirty-two thousand and forty")
  , (1346269, "one million, three hundred and forty-six thousand, two hundred and sixty-nine")
  , (2178309, "two million, one hundred and seventy-eight thousand, three hundred and nine")
  , (3524578, "three million, five hundred and twenty-four thousand, five hundred and seventy-eight")
  , (5702887, "five million, seven hundred and two thousand, eight hundred and eighty-seven")
  , (9227465, "nine million, two hundred and twenty-seven thousand, four hundred and sixty-five")
  , (14930352, "fourteen million, nine hundred and thirty thousand, three hundred and fifty-two")
  , (24157817, "twenty-four million, one hundred and fifty-seven thousand, eight hundred and seventeen")
  , (39088169, "thirty-nine million, eighty-eight thousand, one hundred and sixty-nine")
  , (63245986, "sixty-three million, two hundred and forty-five thousand, nine hundred and eighty-six")
  , (102334155, "one hundred and two million, three hundred and thirty-four thousand, one hundred and fifty-five")
  , (165580141, "one hundred and sixty-five million, five hundred and eighty thousand, one hundred and forty-one")
  , (267914296, "two hundred and sixty-seven million, nine hundred and fourteen thousand, two hundred and ninety-six")
  , (433494437, "four hundred and thirty-three million, four hundred and ninety-four thousand, four hundred and thirty-seven")
  , (701408733, "seven hundred and one million, four hundred and eight thousand, seven hundred and thirty-three")
  , (1134903170, "one billion, one hundred and thirty-four million, nine hundred and three thousand, one hundred and seventy")
  , (1836311903, "one billion, eight hundred and thirty-six million, three hundred and eleven thousand, nine hundred and three")
  , (2971215073, "two billion, nine hundred and seventy-one million, two hundred and fifteen thousand and seventy-three")
  , (4807526976, "four billion, eight hundred and seven million, five hundred and twenty-six thousand, nine hundred and seventy-six")
  , (7778742049, "seven billion, seven hundred and seventy-eight million, seven hundred and forty-two thousand and forty-nine")
  , (12586269025, "twelve billion, five hundred and eighty-six million, two hundred and sixty-nine thousand and twenty-five")
  , (20365011074, "twenty billion, three hundred and sixty-five million, eleven thousand and seventy-four")
  , (32951280099, "thirty-two billion, nine hundred and fifty-one million, two hundred and eighty thousand and ninety-nine")
  , (53316291173, "fifty-three billion, three hundred and sixteen million, two hundred and ninety-one thousand, one hundred and seventy-three")
  , (86267571272, "eighty-six billion, two hundred and sixty-seven million, five hundred and seventy-one thousand, two hundred and seventy-two")
  , (139583862445, "one hundred and thirty-nine billion, five hundred and eighty-three million, eight hundred and sixty-two thousand, four hundred and forty-five")
  , (225851433717, "two hundred and twenty-five billion, eight hundred and fifty-one million, four hundred and thirty-three thousand, seven hundred and seventeen")
  , (365435296162, "three hundred and sixty-five billion, four hundred and thirty-five million, two hundred and ninety-six thousand, one hundred and sixty-two")
  , (591286729879, "five hundred and ninety-one billion, two hundred and eighty-six million, seven hundred and twenty-nine thousand, eight hundred and seventy-nine")
  , (956722026041, "nine hundred and fifty-six billion, seven hundred and twenty-two million, twenty-six thousand and forty-one")
  , (1548008755920, "one trillion, five hundred and forty-eight billion, eight million, seven hundred and fifty-five thousand, nine hundred and twenty")
  , (2504730781961, "two trillion, five hundred and four billion, seven hundred and thirty million, seven hundred and eighty-one thousand, nine hundred and sixty-one")
  , (4052739537881, "four trillion, fifty-two billion, seven hundred and thirty-nine million, five hundred and thirty-seven thousand, eight hundred and eighty-one")
  , (6557470319842, "six trillion, five hundred and fifty-seven billion, four hundred and seventy million, three hundred and nineteen thousand, eight hundred and forty-two")
  , (10610209857723, "ten trillion, six hundred and ten billion, two hundred and nine million, eight hundred and fifty-seven thousand, seven hundred and twenty-three")
  , (17167680177565, "seventeen trillion, one hundred and sixty-seven billion, six hundred and eighty million, one hundred and seventy-seven thousand, five hundred and sixty-five")
  , (27777890035288, "twenty-seven trillion, seven hundred and seventy-seven billion, eight hundred and ninety million, thirty-five thousand, two hundred and eighty-eight")
  , (44945570212853, "forty-four trillion, nine hundred and forty-five billion, five hundred and seventy million, two hundred and twelve thousand, eight hundred and fifty-three")
  , (72723460248141, "seventy-two trillion, seven hundred and twenty-three billion, four hundred and sixty million, two hundred and forty-eight thousand, one hundred and forty-one")
  , (117669030460994, "one hundred and seventeen trillion, six hundred and sixty-nine billion, thirty million, four hundred and sixty thousand, nine hundred and ninety-four")
  , (190392490709135, "one hundred and ninety trillion, three hundred and ninety-two billion, four hundred and ninety million, seven hundred and nine thousand, one hundred and thirty-five")
  , (308061521170129, "three hundred and eight trillion, sixty-one billion, five hundred and twenty-one million, one hundred and seventy thousand, one hundred and twenty-nine")
  , (498454011879264, "four hundred and ninety-eight trillion, four hundred and fifty-four billion, eleven million, eight hundred and seventy-nine thousand, two hundred and sixty-four")
  , (806515533049393, "eight hundred and six trillion, five hundred and fifteen billion, five hundred and thirty-three million, forty-nine thousand, three hundred and ninety-three")
  , (1304969544928657, "one quadrillion, three hundred and four trillion, nine hundred and sixty-nine billion, five hundred and forty-four million, nine hundred and twenty-eight thousand, six hundred and fifty-seven")
  , (2111485077978050, "two quadrillion, one hundred and eleven trillion, four hundred and eighty-five billion, seventy-seven million, nine hundred and seventy-eight thousand and fifty")
  , (3416454622906707, "three quadrillion, four hundred and sixteen trillion, four hundred and fifty-four billion, six hundred and twenty-two million, nine hundred and six thousand, seven hundred and seven")
  , (5527939700884757, "five quadrillion, five hundred and twenty-seven trillion, nine hundred and thirty-nine billion, seven hundred million, eight hundred and eighty-four thousand, seven hundred and fifty-seven")
  , (8944394323791464, "eight quadrillion, nine hundred and forty-four trillion, three hundred and ninety-four billion, three hundred and twenty-three million, seven hundred and ninety-one thousand, four hundred and sixty-four")
  , (14472334024676221, "fourteen quadrillion, four hundred and seventy-two trillion, three hundred and thirty-four billion, twenty-four million, six hundred and seventy-six thousand, two hundred and twenty-one")
  , (23416728348467685, "twenty-three quadrillion, four hundred and sixteen trillion, seven hundred and twenty-eight billion, three hundred and forty-eight million, four hundred and sixty-seven thousand, six hundred and eighty-five")
  , (37889062373143906, "thirty-seven quadrillion, eight hundred and eighty-nine trillion, sixty-two billion, three hundred and seventy-three million, one hundred and forty-three thousand, nine hundred and six")
  , (61305790721611591, "sixty-one quadrillion, three hundred and five trillion, seven hundred and ninety billion, seven hundred and twenty-one million, six hundred and eleven thousand, five hundred and ninety-one")
  , (99194853094755497, "ninety-nine quadrillion, one hundred and ninety-four trillion, eight hundred and fifty-three billion, ninety-four million, seven hundred and fifty-five thousand, four hundred and ninety-seven")
  , (160500643816367088, "one hundred and sixty quadrillion, five hundred trillion, six hundred and forty-three billion, eight hundred and sixteen million, three hundred and sixty-seven thousand and eighty-eight")
  , (259695496911122585, "two hundred and fifty-nine quadrillion, six hundred and ninety-five trillion, four hundred and ninety-six billion, nine hundred and eleven million, one hundred and twenty-two thousand, five hundred and eighty-five")
  , (420196140727489673, "four hundred and twenty quadrillion, one hundred and ninety-six trillion, one hundred and forty billion, seven hundred and twenty-seven million, four hundred and eighty-nine thousand, six hundred and seventy-three")
  , (679891637638612258, "six hundred and seventy-nine quadrillion, eight hundred and ninety-one trillion, six hundred and thirty-seven billion, six hundred and thirty-eight million, six hundred and twelve thousand, two hundred and fifty-eight")
  , (1100087778366101931, "one quintillion, one hundred quadrillion, eighty-seven trillion, seven hundred and seventy-eight billion, three hundred and sixty-six million, one hundred and one thousand, nine hundred and thirty-one")
  , (1779979416004714189, "one quintillion, seven hundred and seventy-nine quadrillion, nine hundred and seventy-nine trillion, four hundred and sixteen billion, four million, seven hundred and fourteen thousand, one hundred and eighty-nine")
  , (2880067194370816120, "two quintillion, eight hundred and eighty quadrillion, sixty-seven trillion, one hundred and ninety-four billion, three hundred and seventy million, eight hundred and sixteen thousand, one hundred and twenty")
  , (4660046610375530309, "four quintillion, six hundred and sixty quadrillion, forty-six trillion, six hundred and ten billion, three hundred and seventy-five million, five hundred and thirty thousand, three hundred and nine")
  , (7540113804746346429, "seven quintillion, five hundred and forty quadrillion, one hundred and thirteen trillion, eight hundred and four billion, seven hundred and forty-six million, three hundred and forty-six thousand, four hundred and twenty-nine")
  , (12200160415121876738, "twelve quintillion, two hundred quadrillion, one hundred and sixty trillion, four hundred and fifteen billion, one hundred and twenty-one million, eight hundred and seventy-six thousand, seven hundred and thirty-eight")
  , (19740274219868223167, "nineteen quintillion, seven hundred and forty quadrillion, two hundred and seventy-four trillion, two hundred and nineteen billion, eight hundred and sixty-eight million, two hundred and twenty-three thousand, one hundred and sixty-seven")
  , (31940434634990099905, "thirty-one quintillion, nine hundred and forty quadrillion, four hundred and thirty-four trillion, six hundred and thirty-four billion, nine hundred and ninety million, ninety-nine thousand, nine hundred and five")
  , (51680708854858323072, "fifty-one quintillion, six hundred and eighty quadrillion, seven hundred and eight trillion, eight hundred and fifty-four billion, eight hundred and fifty-eight million, three hundred and twenty-three thousand and seventy-two")
  , (83621143489848422977, "eighty-three quintillion, six hundred and twenty-one quadrillion, one hundred and forty-three trillion, four hundred and eighty-nine billion, eight hundred and forty-eight million, four hundred and twenty-two thousand, nine hundred and seventy-seven")
  , (135301852344706746049, "one hundred and thirty-five quintillion, three hundred and one quadrillion, eight hundred and fifty-two trillion, three hundred and forty-four billion, seven hundred and six million, seven hundred and forty-six thousand and forty-nine")
  , (218922995834555169026, "two hundred and eighteen quintillion, nine hundred and twenty-two quadrillion, nine hundred and ninety-five trillion, eight hundred and thirty-four billion, five hundred and fifty-five million, one hundred and sixty-nine thousand and twenty-six")
  , (354224848179261915075, "three hundred and fifty-four quintillion, two hundred and twenty-four quadrillion, eight hundred and forty-eight trillion, one hundred and seventy-nine billion, two hundred and sixty-one million, nine hundred and fifteen thousand and seventy-five")
  , (573147844013817084101, "five hundred and seventy-three quintillion, one hundred and forty-seven quadrillion, eight hundred and forty-four trillion, thirteen billion, eight hundred and seventeen million, eighty-four thousand, one hundred and one")
  , (927372692193078999176, "nine hundred and twenty-seven quintillion, three hundred and seventy-two quadrillion, six hundred and ninety-two trillion, one hundred and ninety-three billion, seventy-eight million, nine hundred and ninety-nine thousand, one hundred and seventy-six")
  , (1500520536206896083277, "one sextillion, five hundred quintillion, five hundred and twenty quadrillion, five hundred and thirty-six trillion, two hundred and six billion, eight hundred and ninety-six million, eighty-three thousand, two hundred and seventy-seven")
  , (2427893228399975082453, "two sextillion, four hundred and twenty-seven quintillion, eight hundred and ninety-three quadrillion, two hundred and twenty-eight trillion, three hundred and ninety-nine billion, nine hundred and seventy-five million, eighty-two thousand, four hundred and fifty-three")
  , (3928413764606871165730, "three sextillion, nine hundred and twenty-eight quintillion, four hundred and thirteen quadrillion, seven hundred and sixty-four trillion, six hundred and six billion, eight hundred and seventy-one million, one hundred and sixty-five thousand, seven hundred and thirty")
  , (6356306993006846248183, "six sextillion, three hundred and fifty-six quintillion, three hundred and six quadrillion, nine hundred and ninety-three trillion, six billion, eight hundred and forty-six million, two hundred and forty-eight thousand, one hundred and eighty-three")
  , (10284720757613717413913, "ten sextillion, two hundred and eighty-four quintillion, seven hundred and twenty quadrillion, seven hundred and fifty-seven trillion, six hundred and thirteen billion, seven hundred and seventeen million, four hundred and thirteen thousand, nine hundred and thirteen")
  , (16641027750620563662096, "sixteen sextillion, six hundred and forty-one quintillion, twenty-seven quadrillion, seven hundred and fifty trillion, six hundred and twenty billion, five hundred and sixty-three million, six hundred and sixty-two thousand and ninety-six")
  , (26925748508234281076009, "twenty-six sextillion, nine hundred and twenty-five quintillion, seven hundred and forty-eight quadrillion, five hundred and eight trillion, two hundred and thirty-four billion, two hundred and eighty-one million, seventy-six thousand and nine")
  , (43566776258854844738105, "forty-three sextillion, five hundred and sixty-six quintillion, seven hundred and seventy-six quadrillion, two hundred and fifty-eight trillion, eight hundred and fifty-four billion, eight hundred and forty-four million, seven hundred and thirty-eight thousand, one hundred and five")
  , (70492524767089125814114, "seventy sextillion, four hundred and ninety-two quintillion, five hundred and twenty-four quadrillion, seven hundred and sixty-seven trillion, eighty-nine billion, one hundred and twenty-five million, eight hundred and fourteen thousand, one hundred and fourteen")
  , (114059301025943970552219, "one hundred and fourteen sextillion, fifty-nine quintillion, three hundred and one quadrillion, twenty-five trillion, nine hundred and forty-three billion, nine hundred and seventy million, five hundred and fifty-two thousand, two hundred and nineteen")
  , (1000, "one thousand")
  , (10000, "ten thousand")
  , (100000, "one hundred thousand")
  , (1000000, "one million")
  , (10000000, "ten million")
  , (100000000, "one hundred million")
  , (1000000000, "one billion")
  , (10000000000, "ten billion")
  , (100000000000, "one hundred billion")
  , (1000000000000, "one trillion")
  , (10000000000000, "ten trillion")
  , (100000000000000, "one hundred trillion")
  , (1000000000000000, "one quadrillion")
  , (10000000000000000, "ten quadrillion")
  , (100000000000000000, "one hundred quadrillion")
  , (1000000000000000000, "one quintillion")
  , (10000000000000000000, "ten quintillion")
  , (100000000000000000000, "one hundred quintillion")
  , (1000000000000000000000, "one sextillion")
  , (10000000000000000000000, "ten sextillion")
  , (100000000000000000000000, "one hundred sextillion")
  , (1000000000000000000000000, "one septillion")
  ]

ordinals :: [(Integer, Text)]
ordinals = [
    (0, "zeroth")
  , (1, "first")
  , (2, "second")
  , (3, "third")
  , (4, "fourth")
  , (5, "fifth")
  , (6, "sixth")
  , (7, "seventh")
  , (8, "eighth")
  , (9, "ninth")
  , (10, "tenth")
  , (11, "eleventh")
  , (12, "twelfth")
  , (13, "thirteenth")
  , (14, "fourteenth")
  , (15, "fifteenth")
  , (16, "sixteenth")
  , (17, "seventeenth")
  , (18, "eighteenth")
  , (19, "nineteenth")
  , (20, "twentieth")
  , (21, "twenty-first")
  , (22, "twenty-second")
  , (23, "twenty-third")
  , (24, "twenty-fourth")
  , (25, "twenty-fifth")
  , (26, "twenty-sixth")
  , (27, "twenty-seventh")
  , (28, "twenty-eighth")
  , (29, "twenty-ninth")
  , (30, "thirtieth")
  , (31, "thirty-first")
  , (32, "thirty-second")
  , (33, "thirty-third")
  , (34, "thirty-fourth")
  , (35, "thirty-fifth")
  , (36, "thirty-sixth")
  , (37, "thirty-seventh")
  , (38, "thirty-eighth")
  , (39, "thirty-ninth")
  , (40, "fortieth")
  , (41, "forty-first")
  , (42, "forty-second")
  , (43, "forty-third")
  , (44, "forty-fourth")
  , (45, "forty-fifth")
  , (46, "forty-sixth")
  , (47, "forty-seventh")
  , (48, "forty-eighth")
  , (49, "forty-ninth")
  , (50, "fiftieth")
  , (51, "fifty-first")
  , (52, "fifty-second")
  , (53, "fifty-third")
  , (54, "fifty-fourth")
  , (55, "fifty-fifth")
  , (56, "fifty-sixth")
  , (57, "fifty-seventh")
  , (58, "fifty-eighth")
  , (59, "fifty-ninth")
  , (60, "sixtieth")
  , (61, "sixty-first")
  , (62, "sixty-second")
  , (63, "sixty-third")
  , (64, "sixty-fourth")
  , (65, "sixty-fifth")
  , (66, "sixty-sixth")
  , (67, "sixty-seventh")
  , (68, "sixty-eighth")
  , (69, "sixty-ninth")
  , (70, "seventieth")
  , (71, "seventy-first")
  , (72, "seventy-second")
  , (73, "seventy-third")
  , (74, "seventy-fourth")
  , (75, "seventy-fifth")
  , (76, "seventy-sixth")
  , (77, "seventy-seventh")
  , (78, "seventy-eighth")
  , (79, "seventy-ninth")
  , (80, "eightieth")
  , (81, "eighty-first")
  , (82, "eighty-second")
  , (83, "eighty-third")
  , (84, "eighty-fourth")
  , (85, "eighty-fifth")
  , (86, "eighty-sixth")
  , (87, "eighty-seventh")
  , (88, "eighty-eighth")
  , (89, "eighty-ninth")
  , (90, "ninetieth")
  , (91, "ninety-first")
  , (92, "ninety-second")
  , (93, "ninety-third")
  , (94, "ninety-fourth")
  , (95, "ninety-fifth")
  , (96, "ninety-sixth")
  , (97, "ninety-seventh")
  , (98, "ninety-eighth")
  , (99, "ninety-ninth")
  , (100, "one hundredth")
  , (101, "one hundred and first")
  , (102, "one hundred and second")
  , (103, "one hundred and third")
  , (104, "one hundred and fourth")
  , (105, "one hundred and fifth")
  , (106, "one hundred and sixth")
  , (107, "one hundred and seventh")
  , (108, "one hundred and eighth")
  , (109, "one hundred and ninth")
  , (110, "one hundred and tenth")
  , (111, "one hundred and eleventh")
  , (112, "one hundred and twelfth")
  , (113, "one hundred and thirteenth")
  , (114, "one hundred and fourteenth")
  , (115, "one hundred and fifteenth")
  , (116, "one hundred and sixteenth")
  , (117, "one hundred and seventeenth")
  , (118, "one hundred and eighteenth")
  , (119, "one hundred and nineteenth")
  , (120, "one hundred and twentieth")
  , (121, "one hundred and twenty-first")
  , (122, "one hundred and twenty-second")
  , (123, "one hundred and twenty-third")
  , (124, "one hundred and twenty-fourth")
  , (125, "one hundred and twenty-fifth")
  , (126, "one hundred and twenty-sixth")
  , (127, "one hundred and twenty-seventh")
  , (128, "one hundred and twenty-eighth")
  , (129, "one hundred and twenty-ninth")
  , (130, "one hundred and thirtieth")
  , (131, "one hundred and thirty-first")
  , (132, "one hundred and thirty-second")
  , (133, "one hundred and thirty-third")
  , (134, "one hundred and thirty-fourth")
  , (135, "one hundred and thirty-fifth")
  , (136, "one hundred and thirty-sixth")
  , (137, "one hundred and thirty-seventh")
  , (138, "one hundred and thirty-eighth")
  , (139, "one hundred and thirty-ninth")
  , (140, "one hundred and fortieth")
  , (141, "one hundred and forty-first")
  , (142, "one hundred and forty-second")
  , (143, "one hundred and forty-third")
  , (144, "one hundred and forty-fourth")
  , (145, "one hundred and forty-fifth")
  , (146, "one hundred and forty-sixth")
  , (147, "one hundred and forty-seventh")
  , (148, "one hundred and forty-eighth")
  , (149, "one hundred and forty-ninth")
  , (150, "one hundred and fiftieth")
  , (151, "one hundred and fifty-first")
  , (152, "one hundred and fifty-second")
  , (153, "one hundred and fifty-third")
  , (154, "one hundred and fifty-fourth")
  , (155, "one hundred and fifty-fifth")
  , (156, "one hundred and fifty-sixth")
  , (157, "one hundred and fifty-seventh")
  , (158, "one hundred and fifty-eighth")
  , (159, "one hundred and fifty-ninth")
  , (160, "one hundred and sixtieth")
  , (161, "one hundred and sixty-first")
  , (162, "one hundred and sixty-second")
  , (163, "one hundred and sixty-third")
  , (164, "one hundred and sixty-fourth")
  , (165, "one hundred and sixty-fifth")
  , (166, "one hundred and sixty-sixth")
  , (167, "one hundred and sixty-seventh")
  , (168, "one hundred and sixty-eighth")
  , (169, "one hundred and sixty-ninth")
  , (170, "one hundred and seventieth")
  , (171, "one hundred and seventy-first")
  , (172, "one hundred and seventy-second")
  , (173, "one hundred and seventy-third")
  , (174, "one hundred and seventy-fourth")
  , (175, "one hundred and seventy-fifth")
  , (176, "one hundred and seventy-sixth")
  , (177, "one hundred and seventy-seventh")
  , (178, "one hundred and seventy-eighth")
  , (179, "one hundred and seventy-ninth")
  , (180, "one hundred and eightieth")
  , (181, "one hundred and eighty-first")
  , (182, "one hundred and eighty-second")
  , (183, "one hundred and eighty-third")
  , (184, "one hundred and eighty-fourth")
  , (185, "one hundred and eighty-fifth")
  , (186, "one hundred and eighty-sixth")
  , (187, "one hundred and eighty-seventh")
  , (188, "one hundred and eighty-eighth")
  , (189, "one hundred and eighty-ninth")
  , (190, "one hundred and ninetieth")
  , (191, "one hundred and ninety-first")
  , (192, "one hundred and ninety-second")
  , (193, "one hundred and ninety-third")
  , (194, "one hundred and ninety-fourth")
  , (195, "one hundred and ninety-fifth")
  , (196, "one hundred and ninety-sixth")
  , (197, "one hundred and ninety-seventh")
  , (198, "one hundred and ninety-eighth")
  , (199, "one hundred and ninety-ninth")
  , (200, "two hundredth")
  , (233, "two hundred and thirty-third")
  , (377, "three hundred and seventy-seventh")
  , (610, "six hundred and tenth")
  , (987, "nine hundred and eighty-seventh")
  , (1597, "one thousand, five hundred and ninety-seventh")
  , (2584, "two thousand, five hundred and eighty-fourth")
  , (4181, "four thousand, one hundred and eighty-first")
  , (6765, "six thousand, seven hundred and sixty-fifth")
  , (10946, "ten thousand, nine hundred and forty-sixth")
  , (17711, "seventeen thousand, seven hundred and eleventh")
  , (28657, "twenty-eight thousand, six hundred and fifty-seventh")
  , (46368, "forty-six thousand, three hundred and sixty-eighth")
  , (75025, "seventy-five thousand and twenty-fifth")
  , (121393, "one hundred and twenty-one thousand, three hundred and ninety-third")
  , (196418, "one hundred and ninety-six thousand, four hundred and eighteenth")
  , (317811, "three hundred and seventeen thousand, eight hundred and eleventh")
  , (514229, "five hundred and fourteen thousand, two hundred and twenty-ninth")
  , (832040, "eight hundred and thirty-two thousand and fortieth")
  , (1346269, "one million, three hundred and forty-six thousand, two hundred and sixty-ninth")
  , (2178309, "two million, one hundred and seventy-eight thousand, three hundred and ninth")
  , (3524578, "three million, five hundred and twenty-four thousand, five hundred and seventy-eighth")
  , (5702887, "five million, seven hundred and two thousand, eight hundred and eighty-seventh")
  , (9227465, "nine million, two hundred and twenty-seven thousand, four hundred and sixty-fifth")
  , (14930352, "fourteen million, nine hundred and thirty thousand, three hundred and fifty-second")
  , (24157817, "twenty-four million, one hundred and fifty-seven thousand, eight hundred and seventeenth")
  , (39088169, "thirty-nine million, eighty-eight thousand, one hundred and sixty-ninth")
  , (63245986, "sixty-three million, two hundred and forty-five thousand, nine hundred and eighty-sixth")
  , (102334155, "one hundred and two million, three hundred and thirty-four thousand, one hundred and fifty-fifth")
  , (165580141, "one hundred and sixty-five million, five hundred and eighty thousand, one hundred and forty-first")
  , (267914296, "two hundred and sixty-seven million, nine hundred and fourteen thousand, two hundred and ninety-sixth")
  , (433494437, "four hundred and thirty-three million, four hundred and ninety-four thousand, four hundred and thirty-seventh")
  , (701408733, "seven hundred and one million, four hundred and eight thousand, seven hundred and thirty-third")
  , (1134903170, "one billion, one hundred and thirty-four million, nine hundred and three thousand, one hundred and seventieth")
  , (1836311903, "one billion, eight hundred and thirty-six million, three hundred and eleven thousand, nine hundred and third")
  , (2971215073, "two billion, nine hundred and seventy-one million, two hundred and fifteen thousand and seventy-third")
  , (4807526976, "four billion, eight hundred and seven million, five hundred and twenty-six thousand, nine hundred and seventy-sixth")
  , (7778742049, "seven billion, seven hundred and seventy-eight million, seven hundred and forty-two thousand and forty-ninth")
  , (12586269025, "twelve billion, five hundred and eighty-six million, two hundred and sixty-nine thousand and twenty-fifth")
  , (20365011074, "twenty billion, three hundred and sixty-five million, eleven thousand and seventy-fourth")
  , (32951280099, "thirty-two billion, nine hundred and fifty-one million, two hundred and eighty thousand and ninety-ninth")
  , (53316291173, "fifty-three billion, three hundred and sixteen million, two hundred and ninety-one thousand, one hundred and seventy-third")
  , (86267571272, "eighty-six billion, two hundred and sixty-seven million, five hundred and seventy-one thousand, two hundred and seventy-second")
  , (139583862445, "one hundred and thirty-nine billion, five hundred and eighty-three million, eight hundred and sixty-two thousand, four hundred and forty-fifth")
  , (225851433717, "two hundred and twenty-five billion, eight hundred and fifty-one million, four hundred and thirty-three thousand, seven hundred and seventeenth")
  , (365435296162, "three hundred and sixty-five billion, four hundred and thirty-five million, two hundred and ninety-six thousand, one hundred and sixty-second")
  , (591286729879, "five hundred and ninety-one billion, two hundred and eighty-six million, seven hundred and twenty-nine thousand, eight hundred and seventy-ninth")
  , (956722026041, "nine hundred and fifty-six billion, seven hundred and twenty-two million, twenty-six thousand and forty-first")
  , (1548008755920, "one trillion, five hundred and forty-eight billion, eight million, seven hundred and fifty-five thousand, nine hundred and twentieth")
  , (2504730781961, "two trillion, five hundred and four billion, seven hundred and thirty million, seven hundred and eighty-one thousand, nine hundred and sixty-first")
  , (4052739537881, "four trillion, fifty-two billion, seven hundred and thirty-nine million, five hundred and thirty-seven thousand, eight hundred and eighty-first")
  , (6557470319842, "six trillion, five hundred and fifty-seven billion, four hundred and seventy million, three hundred and nineteen thousand, eight hundred and forty-second")
  , (10610209857723, "ten trillion, six hundred and ten billion, two hundred and nine million, eight hundred and fifty-seven thousand, seven hundred and twenty-third")
  , (17167680177565, "seventeen trillion, one hundred and sixty-seven billion, six hundred and eighty million, one hundred and seventy-seven thousand, five hundred and sixty-fifth")
  , (27777890035288, "twenty-seven trillion, seven hundred and seventy-seven billion, eight hundred and ninety million, thirty-five thousand, two hundred and eighty-eighth")
  , (44945570212853, "forty-four trillion, nine hundred and forty-five billion, five hundred and seventy million, two hundred and twelve thousand, eight hundred and fifty-third")
  , (72723460248141, "seventy-two trillion, seven hundred and twenty-three billion, four hundred and sixty million, two hundred and forty-eight thousand, one hundred and forty-first")
  , (117669030460994, "one hundred and seventeen trillion, six hundred and sixty-nine billion, thirty million, four hundred and sixty thousand, nine hundred and ninety-fourth")
  , (190392490709135, "one hundred and ninety trillion, three hundred and ninety-two billion, four hundred and ninety million, seven hundred and nine thousand, one hundred and thirty-fifth")
  , (308061521170129, "three hundred and eight trillion, sixty-one billion, five hundred and twenty-one million, one hundred and seventy thousand, one hundred and twenty-ninth")
  , (498454011879264, "four hundred and ninety-eight trillion, four hundred and fifty-four billion, eleven million, eight hundred and seventy-nine thousand, two hundred and sixty-fourth")
  , (806515533049393, "eight hundred and six trillion, five hundred and fifteen billion, five hundred and thirty-three million, forty-nine thousand, three hundred and ninety-third")
  , (1304969544928657, "one quadrillion, three hundred and four trillion, nine hundred and sixty-nine billion, five hundred and forty-four million, nine hundred and twenty-eight thousand, six hundred and fifty-seventh")
  , (2111485077978050, "two quadrillion, one hundred and eleven trillion, four hundred and eighty-five billion, seventy-seven million, nine hundred and seventy-eight thousand and fiftieth")
  , (3416454622906707, "three quadrillion, four hundred and sixteen trillion, four hundred and fifty-four billion, six hundred and twenty-two million, nine hundred and six thousand, seven hundred and seventh")
  , (5527939700884757, "five quadrillion, five hundred and twenty-seven trillion, nine hundred and thirty-nine billion, seven hundred million, eight hundred and eighty-four thousand, seven hundred and fifty-seventh")
  , (8944394323791464, "eight quadrillion, nine hundred and forty-four trillion, three hundred and ninety-four billion, three hundred and twenty-three million, seven hundred and ninety-one thousand, four hundred and sixty-fourth")
  , (14472334024676221, "fourteen quadrillion, four hundred and seventy-two trillion, three hundred and thirty-four billion, twenty-four million, six hundred and seventy-six thousand, two hundred and twenty-first")
  , (23416728348467685, "twenty-three quadrillion, four hundred and sixteen trillion, seven hundred and twenty-eight billion, three hundred and forty-eight million, four hundred and sixty-seven thousand, six hundred and eighty-fifth")
  , (37889062373143906, "thirty-seven quadrillion, eight hundred and eighty-nine trillion, sixty-two billion, three hundred and seventy-three million, one hundred and forty-three thousand, nine hundred and sixth")
  , (61305790721611591, "sixty-one quadrillion, three hundred and five trillion, seven hundred and ninety billion, seven hundred and twenty-one million, six hundred and eleven thousand, five hundred and ninety-first")
  , (99194853094755497, "ninety-nine quadrillion, one hundred and ninety-four trillion, eight hundred and fifty-three billion, ninety-four million, seven hundred and fifty-five thousand, four hundred and ninety-seventh")
  , (160500643816367088, "one hundred and sixty quadrillion, five hundred trillion, six hundred and forty-three billion, eight hundred and sixteen million, three hundred and sixty-seven thousand and eighty-eighth")
  , (259695496911122585, "two hundred and fifty-nine quadrillion, six hundred and ninety-five trillion, four hundred and ninety-six billion, nine hundred and eleven million, one hundred and twenty-two thousand, five hundred and eighty-fifth")
  , (420196140727489673, "four hundred and twenty quadrillion, one hundred and ninety-six trillion, one hundred and forty billion, seven hundred and twenty-seven million, four hundred and eighty-nine thousand, six hundred and seventy-third")
  , (679891637638612258, "six hundred and seventy-nine quadrillion, eight hundred and ninety-one trillion, six hundred and thirty-seven billion, six hundred and thirty-eight million, six hundred and twelve thousand, two hundred and fifty-eighth")
  , (1100087778366101931, "one quintillion, one hundred quadrillion, eighty-seven trillion, seven hundred and seventy-eight billion, three hundred and sixty-six million, one hundred and one thousand, nine hundred and thirty-first")
  , (1779979416004714189, "one quintillion, seven hundred and seventy-nine quadrillion, nine hundred and seventy-nine trillion, four hundred and sixteen billion, four million, seven hundred and fourteen thousand, one hundred and eighty-ninth")
  , (2880067194370816120, "two quintillion, eight hundred and eighty quadrillion, sixty-seven trillion, one hundred and ninety-four billion, three hundred and seventy million, eight hundred and sixteen thousand, one hundred and twentieth")
  , (4660046610375530309, "four quintillion, six hundred and sixty quadrillion, forty-six trillion, six hundred and ten billion, three hundred and seventy-five million, five hundred and thirty thousand, three hundred and ninth")
  , (7540113804746346429, "seven quintillion, five hundred and forty quadrillion, one hundred and thirteen trillion, eight hundred and four billion, seven hundred and forty-six million, three hundred and forty-six thousand, four hundred and twenty-ninth")
  , (12200160415121876738, "twelve quintillion, two hundred quadrillion, one hundred and sixty trillion, four hundred and fifteen billion, one hundred and twenty-one million, eight hundred and seventy-six thousand, seven hundred and thirty-eighth")
  , (19740274219868223167, "nineteen quintillion, seven hundred and forty quadrillion, two hundred and seventy-four trillion, two hundred and nineteen billion, eight hundred and sixty-eight million, two hundred and twenty-three thousand, one hundred and sixty-seventh")
  , (31940434634990099905, "thirty-one quintillion, nine hundred and forty quadrillion, four hundred and thirty-four trillion, six hundred and thirty-four billion, nine hundred and ninety million, ninety-nine thousand, nine hundred and fifth")
  , (51680708854858323072, "fifty-one quintillion, six hundred and eighty quadrillion, seven hundred and eight trillion, eight hundred and fifty-four billion, eight hundred and fifty-eight million, three hundred and twenty-three thousand and seventy-second")
  , (83621143489848422977, "eighty-three quintillion, six hundred and twenty-one quadrillion, one hundred and forty-three trillion, four hundred and eighty-nine billion, eight hundred and forty-eight million, four hundred and twenty-two thousand, nine hundred and seventy-seventh")
  , (135301852344706746049, "one hundred and thirty-five quintillion, three hundred and one quadrillion, eight hundred and fifty-two trillion, three hundred and forty-four billion, seven hundred and six million, seven hundred and forty-six thousand and forty-ninth")
  , (218922995834555169026, "two hundred and eighteen quintillion, nine hundred and twenty-two quadrillion, nine hundred and ninety-five trillion, eight hundred and thirty-four billion, five hundred and fifty-five million, one hundred and sixty-nine thousand and twenty-sixth")
  , (354224848179261915075, "three hundred and fifty-four quintillion, two hundred and twenty-four quadrillion, eight hundred and forty-eight trillion, one hundred and seventy-nine billion, two hundred and sixty-one million, nine hundred and fifteen thousand and seventy-fifth")
  , (573147844013817084101, "five hundred and seventy-three quintillion, one hundred and forty-seven quadrillion, eight hundred and forty-four trillion, thirteen billion, eight hundred and seventeen million, eighty-four thousand, one hundred and first")
  , (927372692193078999176, "nine hundred and twenty-seven quintillion, three hundred and seventy-two quadrillion, six hundred and ninety-two trillion, one hundred and ninety-three billion, seventy-eight million, nine hundred and ninety-nine thousand, one hundred and seventy-sixth")
  , (1500520536206896083277, "one sextillion, five hundred quintillion, five hundred and twenty quadrillion, five hundred and thirty-six trillion, two hundred and six billion, eight hundred and ninety-six million, eighty-three thousand, two hundred and seventy-seventh")
  , (2427893228399975082453, "two sextillion, four hundred and twenty-seven quintillion, eight hundred and ninety-three quadrillion, two hundred and twenty-eight trillion, three hundred and ninety-nine billion, nine hundred and seventy-five million, eighty-two thousand, four hundred and fifty-third")
  , (3928413764606871165730, "three sextillion, nine hundred and twenty-eight quintillion, four hundred and thirteen quadrillion, seven hundred and sixty-four trillion, six hundred and six billion, eight hundred and seventy-one million, one hundred and sixty-five thousand, seven hundred and thirtieth")
  , (6356306993006846248183, "six sextillion, three hundred and fifty-six quintillion, three hundred and six quadrillion, nine hundred and ninety-three trillion, six billion, eight hundred and forty-six million, two hundred and forty-eight thousand, one hundred and eighty-third")
  , (10284720757613717413913, "ten sextillion, two hundred and eighty-four quintillion, seven hundred and twenty quadrillion, seven hundred and fifty-seven trillion, six hundred and thirteen billion, seven hundred and seventeen million, four hundred and thirteen thousand, nine hundred and thirteenth")
  , (16641027750620563662096, "sixteen sextillion, six hundred and forty-one quintillion, twenty-seven quadrillion, seven hundred and fifty trillion, six hundred and twenty billion, five hundred and sixty-three million, six hundred and sixty-two thousand and ninety-sixth")
  , (26925748508234281076009, "twenty-six sextillion, nine hundred and twenty-five quintillion, seven hundred and forty-eight quadrillion, five hundred and eight trillion, two hundred and thirty-four billion, two hundred and eighty-one million, seventy-six thousand and ninth")
  , (43566776258854844738105, "forty-three sextillion, five hundred and sixty-six quintillion, seven hundred and seventy-six quadrillion, two hundred and fifty-eight trillion, eight hundred and fifty-four billion, eight hundred and forty-four million, seven hundred and thirty-eight thousand, one hundred and fifth")
  , (70492524767089125814114, "seventy sextillion, four hundred and ninety-two quintillion, five hundred and twenty-four quadrillion, seven hundred and sixty-seven trillion, eighty-nine billion, one hundred and twenty-five million, eight hundred and fourteen thousand, one hundred and fourteenth")
  , (114059301025943970552219, "one hundred and fourteen sextillion, fifty-nine quintillion, three hundred and one quadrillion, twenty-five trillion, nine hundred and forty-three billion, nine hundred and seventy million, five hundred and fifty-two thousand, two hundred and nineteenth")
  , (1000, "one thousandth")
  , (10000, "ten thousandth")
  , (100000, "one hundred thousandth")
  , (1000000, "one millionth")
  , (10000000, "ten millionth")
  , (100000000, "one hundred millionth")
  , (1000000000, "one billionth")
  , (10000000000, "ten billionth")
  , (100000000000, "one hundred billionth")
  , (1000000000000, "one trillionth")
  , (10000000000000, "ten trillionth")
  , (100000000000000, "one hundred trillionth")
  , (1000000000000000, "one quadrillionth")
  , (10000000000000000, "ten quadrillionth")
  , (100000000000000000, "one hundred quadrillionth")
  , (1000000000000000000, "one quintillionth")
  , (10000000000000000000, "ten quintillionth")
  , (100000000000000000000, "one hundred quintillionth")
  , (1000000000000000000000, "one sextillionth")
  , (10000000000000000000000, "ten sextillionth")
  , (100000000000000000000000, "one hundred sextillionth")
  , (1000000000000000000000000, "one septillionth")
  ]

minusCardinals :: [(Integer, Text)]
minusCardinals = [
    (0, "zero")
  , (-1, "minus one")
  , (-2, "minus two")
  , (-3, "minus three")
  , (-4, "minus four")
  , (-5, "minus five")
  , (-6, "minus six")
  , (-7, "minus seven")
  , (-8, "minus eight")
  , (-9, "minus nine")
  , (-10, "minus ten")
  , (-11, "minus eleven")
  , (-12, "minus twelve")
  , (-13, "minus thirteen")
  , (-14, "minus fourteen")
  , (-15, "minus fifteen")
  , (-16, "minus sixteen")
  , (-17, "minus seventeen")
  , (-18, "minus eighteen")
  , (-19, "minus nineteen")
  , (-20, "minus twenty")
  , (-21, "minus twenty-one")
  , (-22, "minus twenty-two")
  , (-23, "minus twenty-three")
  , (-24, "minus twenty-four")
  , (-25, "minus twenty-five")
  , (-26, "minus twenty-six")
  , (-27, "minus twenty-seven")
  , (-28, "minus twenty-eight")
  , (-29, "minus twenty-nine")
  , (-30, "minus thirty")
  , (-31, "minus thirty-one")
  , (-32, "minus thirty-two")
  , (-33, "minus thirty-three")
  , (-34, "minus thirty-four")
  , (-35, "minus thirty-five")
  , (-36, "minus thirty-six")
  , (-37, "minus thirty-seven")
  , (-38, "minus thirty-eight")
  , (-39, "minus thirty-nine")
  , (-40, "minus forty")
  , (-41, "minus forty-one")
  , (-42, "minus forty-two")
  , (-43, "minus forty-three")
  , (-44, "minus forty-four")
  , (-45, "minus forty-five")
  , (-46, "minus forty-six")
  , (-47, "minus forty-seven")
  , (-48, "minus forty-eight")
  , (-49, "minus forty-nine")
  , (-50, "minus fifty")
  , (-51, "minus fifty-one")
  , (-52, "minus fifty-two")
  , (-53, "minus fifty-three")
  , (-54, "minus fifty-four")
  , (-55, "minus fifty-five")
  , (-56, "minus fifty-six")
  , (-57, "minus fifty-seven")
  , (-58, "minus fifty-eight")
  , (-59, "minus fifty-nine")
  , (-60, "minus sixty")
  , (-61, "minus sixty-one")
  , (-62, "minus sixty-two")
  , (-63, "minus sixty-three")
  , (-64, "minus sixty-four")
  , (-65, "minus sixty-five")
  , (-66, "minus sixty-six")
  , (-67, "minus sixty-seven")
  , (-68, "minus sixty-eight")
  , (-69, "minus sixty-nine")
  , (-70, "minus seventy")
  , (-71, "minus seventy-one")
  , (-72, "minus seventy-two")
  , (-73, "minus seventy-three")
  , (-74, "minus seventy-four")
  , (-75, "minus seventy-five")
  , (-76, "minus seventy-six")
  , (-77, "minus seventy-seven")
  , (-78, "minus seventy-eight")
  , (-79, "minus seventy-nine")
  , (-80, "minus eighty")
  , (-81, "minus eighty-one")
  , (-82, "minus eighty-two")
  , (-83, "minus eighty-three")
  , (-84, "minus eighty-four")
  , (-85, "minus eighty-five")
  , (-86, "minus eighty-six")
  , (-87, "minus eighty-seven")
  , (-88, "minus eighty-eight")
  , (-89, "minus eighty-nine")
  , (-90, "minus ninety")
  , (-91, "minus ninety-one")
  , (-92, "minus ninety-two")
  , (-93, "minus ninety-three")
  , (-94, "minus ninety-four")
  , (-95, "minus ninety-five")
  , (-96, "minus ninety-six")
  , (-97, "minus ninety-seven")
  , (-98, "minus ninety-eight")
  , (-99, "minus ninety-nine")
  , (-100, "minus one hundred")
  , (-101, "minus one hundred and one")
  , (-102, "minus one hundred and two")
  , (-103, "minus one hundred and three")
  , (-104, "minus one hundred and four")
  , (-105, "minus one hundred and five")
  , (-106, "minus one hundred and six")
  , (-107, "minus one hundred and seven")
  , (-108, "minus one hundred and eight")
  , (-109, "minus one hundred and nine")
  , (-110, "minus one hundred and ten")
  , (-111, "minus one hundred and eleven")
  , (-112, "minus one hundred and twelve")
  , (-113, "minus one hundred and thirteen")
  , (-114, "minus one hundred and fourteen")
  , (-115, "minus one hundred and fifteen")
  , (-116, "minus one hundred and sixteen")
  , (-117, "minus one hundred and seventeen")
  , (-118, "minus one hundred and eighteen")
  , (-119, "minus one hundred and nineteen")
  , (-120, "minus one hundred and twenty")
  , (-121, "minus one hundred and twenty-one")
  , (-122, "minus one hundred and twenty-two")
  , (-123, "minus one hundred and twenty-three")
  , (-124, "minus one hundred and twenty-four")
  , (-125, "minus one hundred and twenty-five")
  , (-126, "minus one hundred and twenty-six")
  , (-127, "minus one hundred and twenty-seven")
  , (-128, "minus one hundred and twenty-eight")
  , (-129, "minus one hundred and twenty-nine")
  , (-130, "minus one hundred and thirty")
  , (-131, "minus one hundred and thirty-one")
  , (-132, "minus one hundred and thirty-two")
  , (-133, "minus one hundred and thirty-three")
  , (-134, "minus one hundred and thirty-four")
  , (-135, "minus one hundred and thirty-five")
  , (-136, "minus one hundred and thirty-six")
  , (-137, "minus one hundred and thirty-seven")
  , (-138, "minus one hundred and thirty-eight")
  , (-139, "minus one hundred and thirty-nine")
  , (-140, "minus one hundred and forty")
  , (-141, "minus one hundred and forty-one")
  , (-142, "minus one hundred and forty-two")
  , (-143, "minus one hundred and forty-three")
  , (-144, "minus one hundred and forty-four")
  , (-145, "minus one hundred and forty-five")
  , (-146, "minus one hundred and forty-six")
  , (-147, "minus one hundred and forty-seven")
  , (-148, "minus one hundred and forty-eight")
  , (-149, "minus one hundred and forty-nine")
  , (-150, "minus one hundred and fifty")
  , (-151, "minus one hundred and fifty-one")
  , (-152, "minus one hundred and fifty-two")
  , (-153, "minus one hundred and fifty-three")
  , (-154, "minus one hundred and fifty-four")
  , (-155, "minus one hundred and fifty-five")
  , (-156, "minus one hundred and fifty-six")
  , (-157, "minus one hundred and fifty-seven")
  , (-158, "minus one hundred and fifty-eight")
  , (-159, "minus one hundred and fifty-nine")
  , (-160, "minus one hundred and sixty")
  , (-161, "minus one hundred and sixty-one")
  , (-162, "minus one hundred and sixty-two")
  , (-163, "minus one hundred and sixty-three")
  , (-164, "minus one hundred and sixty-four")
  , (-165, "minus one hundred and sixty-five")
  , (-166, "minus one hundred and sixty-six")
  , (-167, "minus one hundred and sixty-seven")
  , (-168, "minus one hundred and sixty-eight")
  , (-169, "minus one hundred and sixty-nine")
  , (-170, "minus one hundred and seventy")
  , (-171, "minus one hundred and seventy-one")
  , (-172, "minus one hundred and seventy-two")
  , (-173, "minus one hundred and seventy-three")
  , (-174, "minus one hundred and seventy-four")
  , (-175, "minus one hundred and seventy-five")
  , (-176, "minus one hundred and seventy-six")
  , (-177, "minus one hundred and seventy-seven")
  , (-178, "minus one hundred and seventy-eight")
  , (-179, "minus one hundred and seventy-nine")
  , (-180, "minus one hundred and eighty")
  , (-181, "minus one hundred and eighty-one")
  , (-182, "minus one hundred and eighty-two")
  , (-183, "minus one hundred and eighty-three")
  , (-184, "minus one hundred and eighty-four")
  , (-185, "minus one hundred and eighty-five")
  , (-186, "minus one hundred and eighty-six")
  , (-187, "minus one hundred and eighty-seven")
  , (-188, "minus one hundred and eighty-eight")
  , (-189, "minus one hundred and eighty-nine")
  , (-190, "minus one hundred and ninety")
  , (-191, "minus one hundred and ninety-one")
  , (-192, "minus one hundred and ninety-two")
  , (-193, "minus one hundred and ninety-three")
  , (-194, "minus one hundred and ninety-four")
  , (-195, "minus one hundred and ninety-five")
  , (-196, "minus one hundred and ninety-six")
  , (-197, "minus one hundred and ninety-seven")
  , (-198, "minus one hundred and ninety-eight")
  , (-199, "minus one hundred and ninety-nine")
  , (-200, "minus two hundred")
  ]

shortOrdinals :: [(Integer, Text)]
shortOrdinals = [
    (0,"0th")
  , (1,"1st")
  , (2,"2nd")
  , (3,"3rd")
  , (4,"4th")
  , (5,"5th")
  , (6,"6th")
  , (7,"7th")
  , (8,"8th")
  , (9,"9th")
  , (10,"10th")
  , (11,"11th")
  , (12,"12th")
  , (13,"13th")
  , (14,"14th")
  , (15,"15th")
  , (16,"16th")
  , (17,"17th")
  , (18,"18th")
  , (19,"19th")
  , (20,"20th")
  , (21,"21st")
  , (22,"22nd")
  , (23,"23rd")
  , (24,"24th")
  , (25,"25th")
  , (26,"26th")
  , (27,"27th")
  , (28,"28th")
  , (29,"29th")
  , (30,"30th")
  , (31,"31st")
  , (32,"32nd")
  , (33,"33rd")
  , (34,"34th")
  , (35,"35th")
  , (36,"36th")
  , (37,"37th")
  , (38,"38th")
  , (39,"39th")
  , (40,"40th")
  , (41,"41st")
  , (42,"42nd")
  , (43,"43rd")
  , (44,"44th")
  , (45,"45th")
  , (46,"46th")
  , (47,"47th")
  , (48,"48th")
  , (49,"49th")
  , (50,"50th")
  , (51,"51st")
  , (52,"52nd")
  , (53,"53rd")
  , (54,"54th")
  , (55,"55th")
  , (56,"56th")
  , (57,"57th")
  , (58,"58th")
  , (59,"59th")
  , (60,"60th")
  , (61,"61st")
  , (62,"62nd")
  , (63,"63rd")
  , (64,"64th")
  , (65,"65th")
  , (66,"66th")
  , (67,"67th")
  , (68,"68th")
  , (69,"69th")
  , (70,"70th")
  , (71,"71st")
  , (72,"72nd")
  , (73,"73rd")
  , (74,"74th")
  , (75,"75th")
  , (76,"76th")
  , (77,"77th")
  , (78,"78th")
  , (79,"79th")
  , (80,"80th")
  , (81,"81st")
  , (82,"82nd")
  , (83,"83rd")
  , (84,"84th")
  , (85,"85th")
  , (86,"86th")
  , (87,"87th")
  , (88,"88th")
  , (89,"89th")
  , (90,"90th")
  , (91,"91st")
  , (92,"92nd")
  , (93,"93rd")
  , (94,"94th")
  , (95,"95th")
  , (96,"96th")
  , (97,"97th")
  , (98,"98th")
  , (99,"99th")
  , (100,"100th")
  , (101,"101st")
  , (102,"102nd")
  , (103,"103rd")
  , (104,"104th")
  , (105,"105th")
  , (106,"106th")
  , (107,"107th")
  , (108,"108th")
  , (109,"109th")
  , (110,"110th")
  , (111,"111th")
  , (112,"112th")
  , (113,"113th")
  , (114,"114th")
  , (115,"115th")
  , (116,"116th")
  , (117,"117th")
  , (118,"118th")
  , (119,"119th")
  , (120,"120th")
  , (121,"121st")
  , (122,"122nd")
  , (123,"123rd")
  , (124,"124th")
  , (125,"125th")
  , (126,"126th")
  , (127,"127th")
  , (128,"128th")
  , (129,"129th")
  , (130,"130th")
  , (131,"131st")
  , (132,"132nd")
  , (133,"133rd")
  , (134,"134th")
  , (135,"135th")
  , (136,"136th")
  , (137,"137th")
  , (138,"138th")
  , (139,"139th")
  , (140,"140th")
  , (141,"141st")
  , (142,"142nd")
  , (143,"143rd")
  , (144,"144th")
  , (145,"145th")
  , (146,"146th")
  , (147,"147th")
  , (148,"148th")
  , (149,"149th")
  , (150,"150th")
  , (151,"151st")
  , (152,"152nd")
  , (153,"153rd")
  , (154,"154th")
  , (155,"155th")
  , (156,"156th")
  , (157,"157th")
  , (158,"158th")
  , (159,"159th")
  , (160,"160th")
  , (161,"161st")
  , (162,"162nd")
  , (163,"163rd")
  , (164,"164th")
  , (165,"165th")
  , (166,"166th")
  , (167,"167th")
  , (168,"168th")
  , (169,"169th")
  , (170,"170th")
  , (171,"171st")
  , (172,"172nd")
  , (173,"173rd")
  , (174,"174th")
  , (175,"175th")
  , (176,"176th")
  , (177,"177th")
  , (178,"178th")
  , (179,"179th")
  , (180,"180th")
  , (181,"181st")
  , (182,"182nd")
  , (183,"183rd")
  , (184,"184th")
  , (185,"185th")
  , (186,"186th")
  , (187,"187th")
  , (188,"188th")
  , (189,"189th")
  , (190,"190th")
  , (191,"191st")
  , (192,"192nd")
  , (193,"193rd")
  , (194,"194th")
  , (195,"195th")
  , (196,"196th")
  , (197,"197th")
  , (198,"198th")
  , (199,"199th")
  , (200,"200th")
  , (233,"233rd")
  , (377,"377th")
  , (610,"610th")
  , (987,"987th")
  , (1597,"1597th")
  , (2584,"2584th")
  , (4181,"4181st")
  , (6765,"6765th")
  , (10946,"10946th")
  , (17711,"17711th")
  , (28657,"28657th")
  , (46368,"46368th")
  , (75025,"75025th")
  , (121393,"121393rd")
  , (196418,"196418th")
  , (317811,"317811th")
  , (514229,"514229th")
  , (832040,"832040th")
  , (1346269,"1346269th")
  , (2178309,"2178309th")
  , (3524578,"3524578th")
  , (5702887,"5702887th")
  , (9227465,"9227465th")
  , (14930352,"14930352nd")
  , (24157817,"24157817th")
  , (39088169,"39088169th")
  , (63245986,"63245986th")
  , (102334155,"102334155th")
  , (165580141,"165580141st")
  , (267914296,"267914296th")
  , (433494437,"433494437th")
  , (701408733,"701408733rd")
  , (1134903170,"1134903170th")
  , (1836311903,"1836311903rd")
  , (2971215073,"2971215073rd")
  , (4807526976,"4807526976th")
  , (7778742049,"7778742049th")
  , (12586269025,"12586269025th")
  , (20365011074,"20365011074th")
  , (32951280099,"32951280099th")
  , (53316291173,"53316291173rd")
  , (86267571272,"86267571272nd")
  , (139583862445,"139583862445th")
  , (225851433717,"225851433717th")
  , (365435296162,"365435296162nd")
  , (591286729879,"591286729879th")
  , (956722026041,"956722026041st")
  , (1548008755920,"1548008755920th")
  , (2504730781961,"2504730781961st")
  , (4052739537881,"4052739537881st")
  , (6557470319842,"6557470319842nd")
  , (10610209857723,"10610209857723rd")
  , (17167680177565,"17167680177565th")
  , (27777890035288,"27777890035288th")
  , (44945570212853,"44945570212853rd")
  , (72723460248141,"72723460248141st")
  , (117669030460994,"117669030460994th")
  , (190392490709135,"190392490709135th")
  , (308061521170129,"308061521170129th")
  , (498454011879264,"498454011879264th")
  , (806515533049393,"806515533049393rd")
  , (1304969544928657,"1304969544928657th")
  , (2111485077978050,"2111485077978050th")
  , (3416454622906707,"3416454622906707th")
  , (5527939700884757,"5527939700884757th")
  , (8944394323791464,"8944394323791464th")
  , (14472334024676221,"14472334024676221st")
  , (23416728348467685,"23416728348467685th")
  , (37889062373143906,"37889062373143906th")
  , (61305790721611591,"61305790721611591st")
  , (99194853094755497,"99194853094755497th")
  , (160500643816367088,"160500643816367088th")
  , (259695496911122585,"259695496911122585th")
  , (420196140727489673,"420196140727489673rd")
  , (679891637638612258,"679891637638612258th")
  , (1100087778366101931,"1100087778366101931st")
  , (1779979416004714189,"1779979416004714189th")
  , (2880067194370816120,"2880067194370816120th")
  , (4660046610375530309,"4660046610375530309th")
  , (7540113804746346429,"7540113804746346429th")
  , (12200160415121876738,"12200160415121876738th")
  , (19740274219868223167,"19740274219868223167th")
  , (31940434634990099905,"31940434634990099905th")
  , (51680708854858323072,"51680708854858323072nd")
  , (83621143489848422977,"83621143489848422977th")
  , (135301852344706746049,"135301852344706746049th")
  , (218922995834555169026,"218922995834555169026th")
  , (354224848179261915075,"354224848179261915075th")
  , (573147844013817084101,"573147844013817084101st")
  , (927372692193078999176,"927372692193078999176th")
  , (1500520536206896083277,"1500520536206896083277th")
  , (2427893228399975082453,"2427893228399975082453rd")
  , (3928413764606871165730,"3928413764606871165730th")
  , (6356306993006846248183,"6356306993006846248183rd")
  , (10284720757613717413913,"10284720757613717413913th")
  , (16641027750620563662096,"16641027750620563662096th")
  , (26925748508234281076009,"26925748508234281076009th")
  , (43566776258854844738105,"43566776258854844738105th")
  , (70492524767089125814114,"70492524767089125814114th")
  , (114059301025943970552219,"114059301025943970552219th")
  , (1000,"1000th")
  , (10000,"10000th")
  , (100000,"100000th")
  , (1000000,"1000000th")
  , (10000000,"10000000th")
  , (100000000,"100000000th")
  , (1000000000,"1000000000th")
  , (10000000000,"10000000000th")
  , (100000000000,"100000000000th")
  , (1000000000000,"1000000000000th")
  , (10000000000000,"10000000000000th")
  , (100000000000000,"100000000000000th")
  , (1000000000000000,"1000000000000000th")
  , (10000000000000000,"10000000000000000th")
  , (100000000000000000,"100000000000000000th")
  , (1000000000000000000,"1000000000000000000th")
  , (10000000000000000000,"10000000000000000000th")
  , (100000000000000000000,"100000000000000000000th")
  , (1000000000000000000000,"1000000000000000000000th")
  , (10000000000000000000000,"10000000000000000000000th")
  , (100000000000000000000000,"100000000000000000000000th")
  , (1000000000000000000000000,"1000000000000000000000000th")
  ]

clockTime :: [(TimeOfDay, Text)]
clockTime = [
    (TimeOfDay 0 0 0,"twelve o'clock at night")
  , (TimeOfDay 0 1 0,"one past twelve at night")
  , (TimeOfDay 0 2 0,"two past twelve at night")
  , (TimeOfDay 0 3 0,"three past twelve at night")
  , (TimeOfDay 0 4 0,"four past twelve at night")
  , (TimeOfDay 0 5 0,"five past twelve at night")
  , (TimeOfDay 0 6 0,"six past twelve at night")
  , (TimeOfDay 0 7 0,"seven past twelve at night")
  , (TimeOfDay 0 8 0,"eight past twelve at night")
  , (TimeOfDay 0 9 0,"nine past twelve at night")
  , (TimeOfDay 0 10 0,"ten past twelve at night")
  , (TimeOfDay 0 11 0,"eleven past twelve at night")
  , (TimeOfDay 0 12 0,"twelve past twelve at night")
  , (TimeOfDay 0 13 0,"thirteen past twelve at night")
  , (TimeOfDay 0 14 0,"fourteen past twelve at night")
  , (TimeOfDay 0 15 0,"quarter past twelve at night")
  , (TimeOfDay 0 16 0,"sixteen past twelve at night")
  , (TimeOfDay 0 17 0,"seventeen past twelve at night")
  , (TimeOfDay 0 18 0,"eighteen past twelve at night")
  , (TimeOfDay 0 19 0,"nineteen past twelve at night")
  , (TimeOfDay 0 20 0,"twenty past twelve at night")
  , (TimeOfDay 0 21 0,"twenty-one past twelve at night")
  , (TimeOfDay 0 22 0,"twenty-two past twelve at night")
  , (TimeOfDay 0 23 0,"twenty-three past twelve at night")
  , (TimeOfDay 0 24 0,"twenty-four past twelve at night")
  , (TimeOfDay 0 25 0,"twenty-five past twelve at night")
  , (TimeOfDay 0 26 0,"twenty-six past twelve at night")
  , (TimeOfDay 0 27 0,"twenty-seven past twelve at night")
  , (TimeOfDay 0 28 0,"twenty-eight past twelve at night")
  , (TimeOfDay 0 29 0,"twenty-nine past twelve at night")
  , (TimeOfDay 0 30 0,"half past twelve at night")
  , (TimeOfDay 0 31 0,"twenty-nine to one at night")
  , (TimeOfDay 0 32 0,"twenty-eight to one at night")
  , (TimeOfDay 0 33 0,"twenty-seven to one at night")
  , (TimeOfDay 0 34 0,"twenty-six to one at night")
  , (TimeOfDay 0 35 0,"twenty-five to one at night")
  , (TimeOfDay 0 36 0,"twenty-four to one at night")
  , (TimeOfDay 0 37 0,"twenty-three to one at night")
  , (TimeOfDay 0 38 0,"twenty-two to one at night")
  , (TimeOfDay 0 39 0,"twenty-one to one at night")
  , (TimeOfDay 0 40 0,"twenty to one at night")
  , (TimeOfDay 0 41 0,"nineteen to one at night")
  , (TimeOfDay 0 42 0,"eighteen to one at night")
  , (TimeOfDay 0 43 0,"seventeen to one at night")
  , (TimeOfDay 0 44 0,"sixteen to one at night")
  , (TimeOfDay 0 45 0,"quarter to one at night")
  , (TimeOfDay 0 46 0,"fourteen to one at night")
  , (TimeOfDay 0 47 0,"thirteen to one at night")
  , (TimeOfDay 0 48 0,"twelve to one at night")
  , (TimeOfDay 0 49 0,"eleven to one at night")
  , (TimeOfDay 0 50 0,"ten to one at night")
  , (TimeOfDay 0 51 0,"nine to one at night")
  , (TimeOfDay 0 52 0,"eight to one at night")
  , (TimeOfDay 0 53 0,"seven to one at night")
  , (TimeOfDay 0 54 0,"six to one at night")
  , (TimeOfDay 0 55 0,"five to one at night")
  , (TimeOfDay 0 56 0,"four to one at night")
  , (TimeOfDay 0 57 0,"three to one at night")
  , (TimeOfDay 0 58 0,"two to one at night")
  , (TimeOfDay 0 59 0,"one to one at night")
  , (TimeOfDay 1 0 0,"one o'clock at night")
  , (TimeOfDay 1 1 0,"one past one at night")
  , (TimeOfDay 1 2 0,"two past one at night")
  , (TimeOfDay 1 3 0,"three past one at night")
  , (TimeOfDay 1 4 0,"four past one at night")
  , (TimeOfDay 1 5 0,"five past one at night")
  , (TimeOfDay 1 6 0,"six past one at night")
  , (TimeOfDay 1 7 0,"seven past one at night")
  , (TimeOfDay 1 8 0,"eight past one at night")
  , (TimeOfDay 1 9 0,"nine past one at night")
  , (TimeOfDay 1 10 0,"ten past one at night")
  , (TimeOfDay 1 11 0,"eleven past one at night")
  , (TimeOfDay 1 12 0,"twelve past one at night")
  , (TimeOfDay 1 13 0,"thirteen past one at night")
  , (TimeOfDay 1 14 0,"fourteen past one at night")
  , (TimeOfDay 1 15 0,"quarter past one at night")
  , (TimeOfDay 1 16 0,"sixteen past one at night")
  , (TimeOfDay 1 17 0,"seventeen past one at night")
  , (TimeOfDay 1 18 0,"eighteen past one at night")
  , (TimeOfDay 1 19 0,"nineteen past one at night")
  , (TimeOfDay 1 20 0,"twenty past one at night")
  , (TimeOfDay 1 21 0,"twenty-one past one at night")
  , (TimeOfDay 1 22 0,"twenty-two past one at night")
  , (TimeOfDay 1 23 0,"twenty-three past one at night")
  , (TimeOfDay 1 24 0,"twenty-four past one at night")
  , (TimeOfDay 1 25 0,"twenty-five past one at night")
  , (TimeOfDay 1 26 0,"twenty-six past one at night")
  , (TimeOfDay 1 27 0,"twenty-seven past one at night")
  , (TimeOfDay 1 28 0,"twenty-eight past one at night")
  , (TimeOfDay 1 29 0,"twenty-nine past one at night")
  , (TimeOfDay 1 30 0,"half past one at night")
  , (TimeOfDay 1 31 0,"twenty-nine to two at night")
  , (TimeOfDay 1 32 0,"twenty-eight to two at night")
  , (TimeOfDay 1 33 0,"twenty-seven to two at night")
  , (TimeOfDay 1 34 0,"twenty-six to two at night")
  , (TimeOfDay 1 35 0,"twenty-five to two at night")
  , (TimeOfDay 1 36 0,"twenty-four to two at night")
  , (TimeOfDay 1 37 0,"twenty-three to two at night")
  , (TimeOfDay 1 38 0,"twenty-two to two at night")
  , (TimeOfDay 1 39 0,"twenty-one to two at night")
  , (TimeOfDay 1 40 0,"twenty to two at night")
  , (TimeOfDay 1 41 0,"nineteen to two at night")
  , (TimeOfDay 1 42 0,"eighteen to two at night")
  , (TimeOfDay 1 43 0,"seventeen to two at night")
  , (TimeOfDay 1 44 0,"sixteen to two at night")
  , (TimeOfDay 1 45 0,"quarter to two at night")
  , (TimeOfDay 1 46 0,"fourteen to two at night")
  , (TimeOfDay 1 47 0,"thirteen to two at night")
  , (TimeOfDay 1 48 0,"twelve to two at night")
  , (TimeOfDay 1 49 0,"eleven to two at night")
  , (TimeOfDay 1 50 0,"ten to two at night")
  , (TimeOfDay 1 51 0,"nine to two at night")
  , (TimeOfDay 1 52 0,"eight to two at night")
  , (TimeOfDay 1 53 0,"seven to two at night")
  , (TimeOfDay 1 54 0,"six to two at night")
  , (TimeOfDay 1 55 0,"five to two at night")
  , (TimeOfDay 1 56 0,"four to two at night")
  , (TimeOfDay 1 57 0,"three to two at night")
  , (TimeOfDay 1 58 0,"two to two at night")
  , (TimeOfDay 1 59 0,"one to two at night")
  , (TimeOfDay 2 0 0,"two o'clock at night")
  , (TimeOfDay 2 1 0,"one past two at night")
  , (TimeOfDay 2 2 0,"two past two at night")
  , (TimeOfDay 2 3 0,"three past two at night")
  , (TimeOfDay 2 4 0,"four past two at night")
  , (TimeOfDay 2 5 0,"five past two at night")
  , (TimeOfDay 2 6 0,"six past two at night")
  , (TimeOfDay 2 7 0,"seven past two at night")
  , (TimeOfDay 2 8 0,"eight past two at night")
  , (TimeOfDay 2 9 0,"nine past two at night")
  , (TimeOfDay 2 10 0,"ten past two at night")
  , (TimeOfDay 2 11 0,"eleven past two at night")
  , (TimeOfDay 2 12 0,"twelve past two at night")
  , (TimeOfDay 2 13 0,"thirteen past two at night")
  , (TimeOfDay 2 14 0,"fourteen past two at night")
  , (TimeOfDay 2 15 0,"quarter past two at night")
  , (TimeOfDay 2 16 0,"sixteen past two at night")
  , (TimeOfDay 2 17 0,"seventeen past two at night")
  , (TimeOfDay 2 18 0,"eighteen past two at night")
  , (TimeOfDay 2 19 0,"nineteen past two at night")
  , (TimeOfDay 2 20 0,"twenty past two at night")
  , (TimeOfDay 2 21 0,"twenty-one past two at night")
  , (TimeOfDay 2 22 0,"twenty-two past two at night")
  , (TimeOfDay 2 23 0,"twenty-three past two at night")
  , (TimeOfDay 2 24 0,"twenty-four past two at night")
  , (TimeOfDay 2 25 0,"twenty-five past two at night")
  , (TimeOfDay 2 26 0,"twenty-six past two at night")
  , (TimeOfDay 2 27 0,"twenty-seven past two at night")
  , (TimeOfDay 2 28 0,"twenty-eight past two at night")
  , (TimeOfDay 2 29 0,"twenty-nine past two at night")
  , (TimeOfDay 2 30 0,"half past two at night")
  , (TimeOfDay 2 31 0,"twenty-nine to three at night")
  , (TimeOfDay 2 32 0,"twenty-eight to three at night")
  , (TimeOfDay 2 33 0,"twenty-seven to three at night")
  , (TimeOfDay 2 34 0,"twenty-six to three at night")
  , (TimeOfDay 2 35 0,"twenty-five to three at night")
  , (TimeOfDay 2 36 0,"twenty-four to three at night")
  , (TimeOfDay 2 37 0,"twenty-three to three at night")
  , (TimeOfDay 2 38 0,"twenty-two to three at night")
  , (TimeOfDay 2 39 0,"twenty-one to three at night")
  , (TimeOfDay 2 40 0,"twenty to three at night")
  , (TimeOfDay 2 41 0,"nineteen to three at night")
  , (TimeOfDay 2 42 0,"eighteen to three at night")
  , (TimeOfDay 2 43 0,"seventeen to three at night")
  , (TimeOfDay 2 44 0,"sixteen to three at night")
  , (TimeOfDay 2 45 0,"quarter to three at night")
  , (TimeOfDay 2 46 0,"fourteen to three at night")
  , (TimeOfDay 2 47 0,"thirteen to three at night")
  , (TimeOfDay 2 48 0,"twelve to three at night")
  , (TimeOfDay 2 49 0,"eleven to three at night")
  , (TimeOfDay 2 50 0,"ten to three at night")
  , (TimeOfDay 2 51 0,"nine to three at night")
  , (TimeOfDay 2 52 0,"eight to three at night")
  , (TimeOfDay 2 53 0,"seven to three at night")
  , (TimeOfDay 2 54 0,"six to three at night")
  , (TimeOfDay 2 55 0,"five to three at night")
  , (TimeOfDay 2 56 0,"four to three at night")
  , (TimeOfDay 2 57 0,"three to three at night")
  , (TimeOfDay 2 58 0,"two to three at night")
  , (TimeOfDay 2 59 0,"one to three at night")
  , (TimeOfDay 3 0 0,"three o'clock at night")
  , (TimeOfDay 3 1 0,"one past three at night")
  , (TimeOfDay 3 2 0,"two past three at night")
  , (TimeOfDay 3 3 0,"three past three at night")
  , (TimeOfDay 3 4 0,"four past three at night")
  , (TimeOfDay 3 5 0,"five past three at night")
  , (TimeOfDay 3 6 0,"six past three at night")
  , (TimeOfDay 3 7 0,"seven past three at night")
  , (TimeOfDay 3 8 0,"eight past three at night")
  , (TimeOfDay 3 9 0,"nine past three at night")
  , (TimeOfDay 3 10 0,"ten past three at night")
  , (TimeOfDay 3 11 0,"eleven past three at night")
  , (TimeOfDay 3 12 0,"twelve past three at night")
  , (TimeOfDay 3 13 0,"thirteen past three at night")
  , (TimeOfDay 3 14 0,"fourteen past three at night")
  , (TimeOfDay 3 15 0,"quarter past three at night")
  , (TimeOfDay 3 16 0,"sixteen past three at night")
  , (TimeOfDay 3 17 0,"seventeen past three at night")
  , (TimeOfDay 3 18 0,"eighteen past three at night")
  , (TimeOfDay 3 19 0,"nineteen past three at night")
  , (TimeOfDay 3 20 0,"twenty past three at night")
  , (TimeOfDay 3 21 0,"twenty-one past three at night")
  , (TimeOfDay 3 22 0,"twenty-two past three at night")
  , (TimeOfDay 3 23 0,"twenty-three past three at night")
  , (TimeOfDay 3 24 0,"twenty-four past three at night")
  , (TimeOfDay 3 25 0,"twenty-five past three at night")
  , (TimeOfDay 3 26 0,"twenty-six past three at night")
  , (TimeOfDay 3 27 0,"twenty-seven past three at night")
  , (TimeOfDay 3 28 0,"twenty-eight past three at night")
  , (TimeOfDay 3 29 0,"twenty-nine past three at night")
  , (TimeOfDay 3 30 0,"half past three at night")
  , (TimeOfDay 3 31 0,"twenty-nine to four at night")
  , (TimeOfDay 3 32 0,"twenty-eight to four at night")
  , (TimeOfDay 3 33 0,"twenty-seven to four at night")
  , (TimeOfDay 3 34 0,"twenty-six to four at night")
  , (TimeOfDay 3 35 0,"twenty-five to four at night")
  , (TimeOfDay 3 36 0,"twenty-four to four at night")
  , (TimeOfDay 3 37 0,"twenty-three to four at night")
  , (TimeOfDay 3 38 0,"twenty-two to four at night")
  , (TimeOfDay 3 39 0,"twenty-one to four at night")
  , (TimeOfDay 3 40 0,"twenty to four at night")
  , (TimeOfDay 3 41 0,"nineteen to four at night")
  , (TimeOfDay 3 42 0,"eighteen to four at night")
  , (TimeOfDay 3 43 0,"seventeen to four at night")
  , (TimeOfDay 3 44 0,"sixteen to four at night")
  , (TimeOfDay 3 45 0,"quarter to four at night")
  , (TimeOfDay 3 46 0,"fourteen to four at night")
  , (TimeOfDay 3 47 0,"thirteen to four at night")
  , (TimeOfDay 3 48 0,"twelve to four at night")
  , (TimeOfDay 3 49 0,"eleven to four at night")
  , (TimeOfDay 3 50 0,"ten to four at night")
  , (TimeOfDay 3 51 0,"nine to four at night")
  , (TimeOfDay 3 52 0,"eight to four at night")
  , (TimeOfDay 3 53 0,"seven to four at night")
  , (TimeOfDay 3 54 0,"six to four at night")
  , (TimeOfDay 3 55 0,"five to four at night")
  , (TimeOfDay 3 56 0,"four to four at night")
  , (TimeOfDay 3 57 0,"three to four at night")
  , (TimeOfDay 3 58 0,"two to four at night")
  , (TimeOfDay 3 59 0,"one to four at night")
  , (TimeOfDay 4 0 0,"four o'clock at night")
  , (TimeOfDay 4 1 0,"one past four at night")
  , (TimeOfDay 4 2 0,"two past four at night")
  , (TimeOfDay 4 3 0,"three past four at night")
  , (TimeOfDay 4 4 0,"four past four at night")
  , (TimeOfDay 4 5 0,"five past four at night")
  , (TimeOfDay 4 6 0,"six past four at night")
  , (TimeOfDay 4 7 0,"seven past four at night")
  , (TimeOfDay 4 8 0,"eight past four at night")
  , (TimeOfDay 4 9 0,"nine past four at night")
  , (TimeOfDay 4 10 0,"ten past four at night")
  , (TimeOfDay 4 11 0,"eleven past four at night")
  , (TimeOfDay 4 12 0,"twelve past four at night")
  , (TimeOfDay 4 13 0,"thirteen past four at night")
  , (TimeOfDay 4 14 0,"fourteen past four at night")
  , (TimeOfDay 4 15 0,"quarter past four at night")
  , (TimeOfDay 4 16 0,"sixteen past four at night")
  , (TimeOfDay 4 17 0,"seventeen past four at night")
  , (TimeOfDay 4 18 0,"eighteen past four at night")
  , (TimeOfDay 4 19 0,"nineteen past four at night")
  , (TimeOfDay 4 20 0,"twenty past four at night")
  , (TimeOfDay 4 21 0,"twenty-one past four at night")
  , (TimeOfDay 4 22 0,"twenty-two past four at night")
  , (TimeOfDay 4 23 0,"twenty-three past four at night")
  , (TimeOfDay 4 24 0,"twenty-four past four at night")
  , (TimeOfDay 4 25 0,"twenty-five past four at night")
  , (TimeOfDay 4 26 0,"twenty-six past four at night")
  , (TimeOfDay 4 27 0,"twenty-seven past four at night")
  , (TimeOfDay 4 28 0,"twenty-eight past four at night")
  , (TimeOfDay 4 29 0,"twenty-nine past four at night")
  , (TimeOfDay 4 30 0,"half past four at night")
  , (TimeOfDay 4 31 0,"twenty-nine to five at night")
  , (TimeOfDay 4 32 0,"twenty-eight to five at night")
  , (TimeOfDay 4 33 0,"twenty-seven to five at night")
  , (TimeOfDay 4 34 0,"twenty-six to five at night")
  , (TimeOfDay 4 35 0,"twenty-five to five at night")
  , (TimeOfDay 4 36 0,"twenty-four to five at night")
  , (TimeOfDay 4 37 0,"twenty-three to five at night")
  , (TimeOfDay 4 38 0,"twenty-two to five at night")
  , (TimeOfDay 4 39 0,"twenty-one to five at night")
  , (TimeOfDay 4 40 0,"twenty to five at night")
  , (TimeOfDay 4 41 0,"nineteen to five at night")
  , (TimeOfDay 4 42 0,"eighteen to five at night")
  , (TimeOfDay 4 43 0,"seventeen to five at night")
  , (TimeOfDay 4 44 0,"sixteen to five at night")
  , (TimeOfDay 4 45 0,"quarter to five at night")
  , (TimeOfDay 4 46 0,"fourteen to five at night")
  , (TimeOfDay 4 47 0,"thirteen to five at night")
  , (TimeOfDay 4 48 0,"twelve to five at night")
  , (TimeOfDay 4 49 0,"eleven to five at night")
  , (TimeOfDay 4 50 0,"ten to five at night")
  , (TimeOfDay 4 51 0,"nine to five at night")
  , (TimeOfDay 4 52 0,"eight to five at night")
  , (TimeOfDay 4 53 0,"seven to five at night")
  , (TimeOfDay 4 54 0,"six to five at night")
  , (TimeOfDay 4 55 0,"five to five at night")
  , (TimeOfDay 4 56 0,"four to five at night")
  , (TimeOfDay 4 57 0,"three to five at night")
  , (TimeOfDay 4 58 0,"two to five at night")
  , (TimeOfDay 4 59 0,"one to five at night")
  , (TimeOfDay 5 0 0,"five o'clock at night")
  , (TimeOfDay 5 1 0,"one past five at night")
  , (TimeOfDay 5 2 0,"two past five at night")
  , (TimeOfDay 5 3 0,"three past five at night")
  , (TimeOfDay 5 4 0,"four past five at night")
  , (TimeOfDay 5 5 0,"five past five at night")
  , (TimeOfDay 5 6 0,"six past five at night")
  , (TimeOfDay 5 7 0,"seven past five at night")
  , (TimeOfDay 5 8 0,"eight past five at night")
  , (TimeOfDay 5 9 0,"nine past five at night")
  , (TimeOfDay 5 10 0,"ten past five at night")
  , (TimeOfDay 5 11 0,"eleven past five at night")
  , (TimeOfDay 5 12 0,"twelve past five at night")
  , (TimeOfDay 5 13 0,"thirteen past five at night")
  , (TimeOfDay 5 14 0,"fourteen past five at night")
  , (TimeOfDay 5 15 0,"quarter past five at night")
  , (TimeOfDay 5 16 0,"sixteen past five at night")
  , (TimeOfDay 5 17 0,"seventeen past five at night")
  , (TimeOfDay 5 18 0,"eighteen past five at night")
  , (TimeOfDay 5 19 0,"nineteen past five at night")
  , (TimeOfDay 5 20 0,"twenty past five at night")
  , (TimeOfDay 5 21 0,"twenty-one past five at night")
  , (TimeOfDay 5 22 0,"twenty-two past five at night")
  , (TimeOfDay 5 23 0,"twenty-three past five at night")
  , (TimeOfDay 5 24 0,"twenty-four past five at night")
  , (TimeOfDay 5 25 0,"twenty-five past five at night")
  , (TimeOfDay 5 26 0,"twenty-six past five at night")
  , (TimeOfDay 5 27 0,"twenty-seven past five at night")
  , (TimeOfDay 5 28 0,"twenty-eight past five at night")
  , (TimeOfDay 5 29 0,"twenty-nine past five at night")
  , (TimeOfDay 5 30 0,"half past five at night")
  , (TimeOfDay 5 31 0,"twenty-nine to six at night")
  , (TimeOfDay 5 32 0,"twenty-eight to six at night")
  , (TimeOfDay 5 33 0,"twenty-seven to six at night")
  , (TimeOfDay 5 34 0,"twenty-six to six at night")
  , (TimeOfDay 5 35 0,"twenty-five to six at night")
  , (TimeOfDay 5 36 0,"twenty-four to six at night")
  , (TimeOfDay 5 37 0,"twenty-three to six at night")
  , (TimeOfDay 5 38 0,"twenty-two to six at night")
  , (TimeOfDay 5 39 0,"twenty-one to six at night")
  , (TimeOfDay 5 40 0,"twenty to six at night")
  , (TimeOfDay 5 41 0,"nineteen to six at night")
  , (TimeOfDay 5 42 0,"eighteen to six at night")
  , (TimeOfDay 5 43 0,"seventeen to six at night")
  , (TimeOfDay 5 44 0,"sixteen to six at night")
  , (TimeOfDay 5 45 0,"quarter to six at night")
  , (TimeOfDay 5 46 0,"fourteen to six at night")
  , (TimeOfDay 5 47 0,"thirteen to six at night")
  , (TimeOfDay 5 48 0,"twelve to six at night")
  , (TimeOfDay 5 49 0,"eleven to six at night")
  , (TimeOfDay 5 50 0,"ten to six at night")
  , (TimeOfDay 5 51 0,"nine to six at night")
  , (TimeOfDay 5 52 0,"eight to six at night")
  , (TimeOfDay 5 53 0,"seven to six at night")
  , (TimeOfDay 5 54 0,"six to six at night")
  , (TimeOfDay 5 55 0,"five to six at night")
  , (TimeOfDay 5 56 0,"four to six at night")
  , (TimeOfDay 5 57 0,"three to six at night")
  , (TimeOfDay 5 58 0,"two to six at night")
  , (TimeOfDay 5 59 0,"one to six at night")
  , (TimeOfDay 6 0 0,"six o'clock in the morning")
  , (TimeOfDay 6 1 0,"one past six in the morning")
  , (TimeOfDay 6 2 0,"two past six in the morning")
  , (TimeOfDay 6 3 0,"three past six in the morning")
  , (TimeOfDay 6 4 0,"four past six in the morning")
  , (TimeOfDay 6 5 0,"five past six in the morning")
  , (TimeOfDay 6 6 0,"six past six in the morning")
  , (TimeOfDay 6 7 0,"seven past six in the morning")
  , (TimeOfDay 6 8 0,"eight past six in the morning")
  , (TimeOfDay 6 9 0,"nine past six in the morning")
  , (TimeOfDay 6 10 0,"ten past six in the morning")
  , (TimeOfDay 6 11 0,"eleven past six in the morning")
  , (TimeOfDay 6 12 0,"twelve past six in the morning")
  , (TimeOfDay 6 13 0,"thirteen past six in the morning")
  , (TimeOfDay 6 14 0,"fourteen past six in the morning")
  , (TimeOfDay 6 15 0,"quarter past six in the morning")
  , (TimeOfDay 6 16 0,"sixteen past six in the morning")
  , (TimeOfDay 6 17 0,"seventeen past six in the morning")
  , (TimeOfDay 6 18 0,"eighteen past six in the morning")
  , (TimeOfDay 6 19 0,"nineteen past six in the morning")
  , (TimeOfDay 6 20 0,"twenty past six in the morning")
  , (TimeOfDay 6 21 0,"twenty-one past six in the morning")
  , (TimeOfDay 6 22 0,"twenty-two past six in the morning")
  , (TimeOfDay 6 23 0,"twenty-three past six in the morning")
  , (TimeOfDay 6 24 0,"twenty-four past six in the morning")
  , (TimeOfDay 6 25 0,"twenty-five past six in the morning")
  , (TimeOfDay 6 26 0,"twenty-six past six in the morning")
  , (TimeOfDay 6 27 0,"twenty-seven past six in the morning")
  , (TimeOfDay 6 28 0,"twenty-eight past six in the morning")
  , (TimeOfDay 6 29 0,"twenty-nine past six in the morning")
  , (TimeOfDay 6 30 0,"half past six in the morning")
  , (TimeOfDay 6 31 0,"twenty-nine to seven in the morning")
  , (TimeOfDay 6 32 0,"twenty-eight to seven in the morning")
  , (TimeOfDay 6 33 0,"twenty-seven to seven in the morning")
  , (TimeOfDay 6 34 0,"twenty-six to seven in the morning")
  , (TimeOfDay 6 35 0,"twenty-five to seven in the morning")
  , (TimeOfDay 6 36 0,"twenty-four to seven in the morning")
  , (TimeOfDay 6 37 0,"twenty-three to seven in the morning")
  , (TimeOfDay 6 38 0,"twenty-two to seven in the morning")
  , (TimeOfDay 6 39 0,"twenty-one to seven in the morning")
  , (TimeOfDay 6 40 0,"twenty to seven in the morning")
  , (TimeOfDay 6 41 0,"nineteen to seven in the morning")
  , (TimeOfDay 6 42 0,"eighteen to seven in the morning")
  , (TimeOfDay 6 43 0,"seventeen to seven in the morning")
  , (TimeOfDay 6 44 0,"sixteen to seven in the morning")
  , (TimeOfDay 6 45 0,"quarter to seven in the morning")
  , (TimeOfDay 6 46 0,"fourteen to seven in the morning")
  , (TimeOfDay 6 47 0,"thirteen to seven in the morning")
  , (TimeOfDay 6 48 0,"twelve to seven in the morning")
  , (TimeOfDay 6 49 0,"eleven to seven in the morning")
  , (TimeOfDay 6 50 0,"ten to seven in the morning")
  , (TimeOfDay 6 51 0,"nine to seven in the morning")
  , (TimeOfDay 6 52 0,"eight to seven in the morning")
  , (TimeOfDay 6 53 0,"seven to seven in the morning")
  , (TimeOfDay 6 54 0,"six to seven in the morning")
  , (TimeOfDay 6 55 0,"five to seven in the morning")
  , (TimeOfDay 6 56 0,"four to seven in the morning")
  , (TimeOfDay 6 57 0,"three to seven in the morning")
  , (TimeOfDay 6 58 0,"two to seven in the morning")
  , (TimeOfDay 6 59 0,"one to seven in the morning")
  , (TimeOfDay 7 0 0,"seven o'clock in the morning")
  , (TimeOfDay 7 1 0,"one past seven in the morning")
  , (TimeOfDay 7 2 0,"two past seven in the morning")
  , (TimeOfDay 7 3 0,"three past seven in the morning")
  , (TimeOfDay 7 4 0,"four past seven in the morning")
  , (TimeOfDay 7 5 0,"five past seven in the morning")
  , (TimeOfDay 7 6 0,"six past seven in the morning")
  , (TimeOfDay 7 7 0,"seven past seven in the morning")
  , (TimeOfDay 7 8 0,"eight past seven in the morning")
  , (TimeOfDay 7 9 0,"nine past seven in the morning")
  , (TimeOfDay 7 10 0,"ten past seven in the morning")
  , (TimeOfDay 7 11 0,"eleven past seven in the morning")
  , (TimeOfDay 7 12 0,"twelve past seven in the morning")
  , (TimeOfDay 7 13 0,"thirteen past seven in the morning")
  , (TimeOfDay 7 14 0,"fourteen past seven in the morning")
  , (TimeOfDay 7 15 0,"quarter past seven in the morning")
  , (TimeOfDay 7 16 0,"sixteen past seven in the morning")
  , (TimeOfDay 7 17 0,"seventeen past seven in the morning")
  , (TimeOfDay 7 18 0,"eighteen past seven in the morning")
  , (TimeOfDay 7 19 0,"nineteen past seven in the morning")
  , (TimeOfDay 7 20 0,"twenty past seven in the morning")
  , (TimeOfDay 7 21 0,"twenty-one past seven in the morning")
  , (TimeOfDay 7 22 0,"twenty-two past seven in the morning")
  , (TimeOfDay 7 23 0,"twenty-three past seven in the morning")
  , (TimeOfDay 7 24 0,"twenty-four past seven in the morning")
  , (TimeOfDay 7 25 0,"twenty-five past seven in the morning")
  , (TimeOfDay 7 26 0,"twenty-six past seven in the morning")
  , (TimeOfDay 7 27 0,"twenty-seven past seven in the morning")
  , (TimeOfDay 7 28 0,"twenty-eight past seven in the morning")
  , (TimeOfDay 7 29 0,"twenty-nine past seven in the morning")
  , (TimeOfDay 7 30 0,"half past seven in the morning")
  , (TimeOfDay 7 31 0,"twenty-nine to eight in the morning")
  , (TimeOfDay 7 32 0,"twenty-eight to eight in the morning")
  , (TimeOfDay 7 33 0,"twenty-seven to eight in the morning")
  , (TimeOfDay 7 34 0,"twenty-six to eight in the morning")
  , (TimeOfDay 7 35 0,"twenty-five to eight in the morning")
  , (TimeOfDay 7 36 0,"twenty-four to eight in the morning")
  , (TimeOfDay 7 37 0,"twenty-three to eight in the morning")
  , (TimeOfDay 7 38 0,"twenty-two to eight in the morning")
  , (TimeOfDay 7 39 0,"twenty-one to eight in the morning")
  , (TimeOfDay 7 40 0,"twenty to eight in the morning")
  , (TimeOfDay 7 41 0,"nineteen to eight in the morning")
  , (TimeOfDay 7 42 0,"eighteen to eight in the morning")
  , (TimeOfDay 7 43 0,"seventeen to eight in the morning")
  , (TimeOfDay 7 44 0,"sixteen to eight in the morning")
  , (TimeOfDay 7 45 0,"quarter to eight in the morning")
  , (TimeOfDay 7 46 0,"fourteen to eight in the morning")
  , (TimeOfDay 7 47 0,"thirteen to eight in the morning")
  , (TimeOfDay 7 48 0,"twelve to eight in the morning")
  , (TimeOfDay 7 49 0,"eleven to eight in the morning")
  , (TimeOfDay 7 50 0,"ten to eight in the morning")
  , (TimeOfDay 7 51 0,"nine to eight in the morning")
  , (TimeOfDay 7 52 0,"eight to eight in the morning")
  , (TimeOfDay 7 53 0,"seven to eight in the morning")
  , (TimeOfDay 7 54 0,"six to eight in the morning")
  , (TimeOfDay 7 55 0,"five to eight in the morning")
  , (TimeOfDay 7 56 0,"four to eight in the morning")
  , (TimeOfDay 7 57 0,"three to eight in the morning")
  , (TimeOfDay 7 58 0,"two to eight in the morning")
  , (TimeOfDay 7 59 0,"one to eight in the morning")
  , (TimeOfDay 8 0 0,"eight o'clock in the morning")
  , (TimeOfDay 8 1 0,"one past eight in the morning")
  , (TimeOfDay 8 2 0,"two past eight in the morning")
  , (TimeOfDay 8 3 0,"three past eight in the morning")
  , (TimeOfDay 8 4 0,"four past eight in the morning")
  , (TimeOfDay 8 5 0,"five past eight in the morning")
  , (TimeOfDay 8 6 0,"six past eight in the morning")
  , (TimeOfDay 8 7 0,"seven past eight in the morning")
  , (TimeOfDay 8 8 0,"eight past eight in the morning")
  , (TimeOfDay 8 9 0,"nine past eight in the morning")
  , (TimeOfDay 8 10 0,"ten past eight in the morning")
  , (TimeOfDay 8 11 0,"eleven past eight in the morning")
  , (TimeOfDay 8 12 0,"twelve past eight in the morning")
  , (TimeOfDay 8 13 0,"thirteen past eight in the morning")
  , (TimeOfDay 8 14 0,"fourteen past eight in the morning")
  , (TimeOfDay 8 15 0,"quarter past eight in the morning")
  , (TimeOfDay 8 16 0,"sixteen past eight in the morning")
  , (TimeOfDay 8 17 0,"seventeen past eight in the morning")
  , (TimeOfDay 8 18 0,"eighteen past eight in the morning")
  , (TimeOfDay 8 19 0,"nineteen past eight in the morning")
  , (TimeOfDay 8 20 0,"twenty past eight in the morning")
  , (TimeOfDay 8 21 0,"twenty-one past eight in the morning")
  , (TimeOfDay 8 22 0,"twenty-two past eight in the morning")
  , (TimeOfDay 8 23 0,"twenty-three past eight in the morning")
  , (TimeOfDay 8 24 0,"twenty-four past eight in the morning")
  , (TimeOfDay 8 25 0,"twenty-five past eight in the morning")
  , (TimeOfDay 8 26 0,"twenty-six past eight in the morning")
  , (TimeOfDay 8 27 0,"twenty-seven past eight in the morning")
  , (TimeOfDay 8 28 0,"twenty-eight past eight in the morning")
  , (TimeOfDay 8 29 0,"twenty-nine past eight in the morning")
  , (TimeOfDay 8 30 0,"half past eight in the morning")
  , (TimeOfDay 8 31 0,"twenty-nine to nine in the morning")
  , (TimeOfDay 8 32 0,"twenty-eight to nine in the morning")
  , (TimeOfDay 8 33 0,"twenty-seven to nine in the morning")
  , (TimeOfDay 8 34 0,"twenty-six to nine in the morning")
  , (TimeOfDay 8 35 0,"twenty-five to nine in the morning")
  , (TimeOfDay 8 36 0,"twenty-four to nine in the morning")
  , (TimeOfDay 8 37 0,"twenty-three to nine in the morning")
  , (TimeOfDay 8 38 0,"twenty-two to nine in the morning")
  , (TimeOfDay 8 39 0,"twenty-one to nine in the morning")
  , (TimeOfDay 8 40 0,"twenty to nine in the morning")
  , (TimeOfDay 8 41 0,"nineteen to nine in the morning")
  , (TimeOfDay 8 42 0,"eighteen to nine in the morning")
  , (TimeOfDay 8 43 0,"seventeen to nine in the morning")
  , (TimeOfDay 8 44 0,"sixteen to nine in the morning")
  , (TimeOfDay 8 45 0,"quarter to nine in the morning")
  , (TimeOfDay 8 46 0,"fourteen to nine in the morning")
  , (TimeOfDay 8 47 0,"thirteen to nine in the morning")
  , (TimeOfDay 8 48 0,"twelve to nine in the morning")
  , (TimeOfDay 8 49 0,"eleven to nine in the morning")
  , (TimeOfDay 8 50 0,"ten to nine in the morning")
  , (TimeOfDay 8 51 0,"nine to nine in the morning")
  , (TimeOfDay 8 52 0,"eight to nine in the morning")
  , (TimeOfDay 8 53 0,"seven to nine in the morning")
  , (TimeOfDay 8 54 0,"six to nine in the morning")
  , (TimeOfDay 8 55 0,"five to nine in the morning")
  , (TimeOfDay 8 56 0,"four to nine in the morning")
  , (TimeOfDay 8 57 0,"three to nine in the morning")
  , (TimeOfDay 8 58 0,"two to nine in the morning")
  , (TimeOfDay 8 59 0,"one to nine in the morning")
  , (TimeOfDay 9 0 0,"nine o'clock in the morning")
  , (TimeOfDay 9 1 0,"one past nine in the morning")
  , (TimeOfDay 9 2 0,"two past nine in the morning")
  , (TimeOfDay 9 3 0,"three past nine in the morning")
  , (TimeOfDay 9 4 0,"four past nine in the morning")
  , (TimeOfDay 9 5 0,"five past nine in the morning")
  , (TimeOfDay 9 6 0,"six past nine in the morning")
  , (TimeOfDay 9 7 0,"seven past nine in the morning")
  , (TimeOfDay 9 8 0,"eight past nine in the morning")
  , (TimeOfDay 9 9 0,"nine past nine in the morning")
  , (TimeOfDay 9 10 0,"ten past nine in the morning")
  , (TimeOfDay 9 11 0,"eleven past nine in the morning")
  , (TimeOfDay 9 12 0,"twelve past nine in the morning")
  , (TimeOfDay 9 13 0,"thirteen past nine in the morning")
  , (TimeOfDay 9 14 0,"fourteen past nine in the morning")
  , (TimeOfDay 9 15 0,"quarter past nine in the morning")
  , (TimeOfDay 9 16 0,"sixteen past nine in the morning")
  , (TimeOfDay 9 17 0,"seventeen past nine in the morning")
  , (TimeOfDay 9 18 0,"eighteen past nine in the morning")
  , (TimeOfDay 9 19 0,"nineteen past nine in the morning")
  , (TimeOfDay 9 20 0,"twenty past nine in the morning")
  , (TimeOfDay 9 21 0,"twenty-one past nine in the morning")
  , (TimeOfDay 9 22 0,"twenty-two past nine in the morning")
  , (TimeOfDay 9 23 0,"twenty-three past nine in the morning")
  , (TimeOfDay 9 24 0,"twenty-four past nine in the morning")
  , (TimeOfDay 9 25 0,"twenty-five past nine in the morning")
  , (TimeOfDay 9 26 0,"twenty-six past nine in the morning")
  , (TimeOfDay 9 27 0,"twenty-seven past nine in the morning")
  , (TimeOfDay 9 28 0,"twenty-eight past nine in the morning")
  , (TimeOfDay 9 29 0,"twenty-nine past nine in the morning")
  , (TimeOfDay 9 30 0,"half past nine in the morning")
  , (TimeOfDay 9 31 0,"twenty-nine to ten in the morning")
  , (TimeOfDay 9 32 0,"twenty-eight to ten in the morning")
  , (TimeOfDay 9 33 0,"twenty-seven to ten in the morning")
  , (TimeOfDay 9 34 0,"twenty-six to ten in the morning")
  , (TimeOfDay 9 35 0,"twenty-five to ten in the morning")
  , (TimeOfDay 9 36 0,"twenty-four to ten in the morning")
  , (TimeOfDay 9 37 0,"twenty-three to ten in the morning")
  , (TimeOfDay 9 38 0,"twenty-two to ten in the morning")
  , (TimeOfDay 9 39 0,"twenty-one to ten in the morning")
  , (TimeOfDay 9 40 0,"twenty to ten in the morning")
  , (TimeOfDay 9 41 0,"nineteen to ten in the morning")
  , (TimeOfDay 9 42 0,"eighteen to ten in the morning")
  , (TimeOfDay 9 43 0,"seventeen to ten in the morning")
  , (TimeOfDay 9 44 0,"sixteen to ten in the morning")
  , (TimeOfDay 9 45 0,"quarter to ten in the morning")
  , (TimeOfDay 9 46 0,"fourteen to ten in the morning")
  , (TimeOfDay 9 47 0,"thirteen to ten in the morning")
  , (TimeOfDay 9 48 0,"twelve to ten in the morning")
  , (TimeOfDay 9 49 0,"eleven to ten in the morning")
  , (TimeOfDay 9 50 0,"ten to ten in the morning")
  , (TimeOfDay 9 51 0,"nine to ten in the morning")
  , (TimeOfDay 9 52 0,"eight to ten in the morning")
  , (TimeOfDay 9 53 0,"seven to ten in the morning")
  , (TimeOfDay 9 54 0,"six to ten in the morning")
  , (TimeOfDay 9 55 0,"five to ten in the morning")
  , (TimeOfDay 9 56 0,"four to ten in the morning")
  , (TimeOfDay 9 57 0,"three to ten in the morning")
  , (TimeOfDay 9 58 0,"two to ten in the morning")
  , (TimeOfDay 9 59 0,"one to ten in the morning")
  , (TimeOfDay 10 0 0,"ten o'clock in the morning")
  , (TimeOfDay 10 1 0,"one past ten in the morning")
  , (TimeOfDay 10 2 0,"two past ten in the morning")
  , (TimeOfDay 10 3 0,"three past ten in the morning")
  , (TimeOfDay 10 4 0,"four past ten in the morning")
  , (TimeOfDay 10 5 0,"five past ten in the morning")
  , (TimeOfDay 10 6 0,"six past ten in the morning")
  , (TimeOfDay 10 7 0,"seven past ten in the morning")
  , (TimeOfDay 10 8 0,"eight past ten in the morning")
  , (TimeOfDay 10 9 0,"nine past ten in the morning")
  , (TimeOfDay 10 10 0,"ten past ten in the morning")
  , (TimeOfDay 10 11 0,"eleven past ten in the morning")
  , (TimeOfDay 10 12 0,"twelve past ten in the morning")
  , (TimeOfDay 10 13 0,"thirteen past ten in the morning")
  , (TimeOfDay 10 14 0,"fourteen past ten in the morning")
  , (TimeOfDay 10 15 0,"quarter past ten in the morning")
  , (TimeOfDay 10 16 0,"sixteen past ten in the morning")
  , (TimeOfDay 10 17 0,"seventeen past ten in the morning")
  , (TimeOfDay 10 18 0,"eighteen past ten in the morning")
  , (TimeOfDay 10 19 0,"nineteen past ten in the morning")
  , (TimeOfDay 10 20 0,"twenty past ten in the morning")
  , (TimeOfDay 10 21 0,"twenty-one past ten in the morning")
  , (TimeOfDay 10 22 0,"twenty-two past ten in the morning")
  , (TimeOfDay 10 23 0,"twenty-three past ten in the morning")
  , (TimeOfDay 10 24 0,"twenty-four past ten in the morning")
  , (TimeOfDay 10 25 0,"twenty-five past ten in the morning")
  , (TimeOfDay 10 26 0,"twenty-six past ten in the morning")
  , (TimeOfDay 10 27 0,"twenty-seven past ten in the morning")
  , (TimeOfDay 10 28 0,"twenty-eight past ten in the morning")
  , (TimeOfDay 10 29 0,"twenty-nine past ten in the morning")
  , (TimeOfDay 10 30 0,"half past ten in the morning")
  , (TimeOfDay 10 31 0,"twenty-nine to eleven in the morning")
  , (TimeOfDay 10 32 0,"twenty-eight to eleven in the morning")
  , (TimeOfDay 10 33 0,"twenty-seven to eleven in the morning")
  , (TimeOfDay 10 34 0,"twenty-six to eleven in the morning")
  , (TimeOfDay 10 35 0,"twenty-five to eleven in the morning")
  , (TimeOfDay 10 36 0,"twenty-four to eleven in the morning")
  , (TimeOfDay 10 37 0,"twenty-three to eleven in the morning")
  , (TimeOfDay 10 38 0,"twenty-two to eleven in the morning")
  , (TimeOfDay 10 39 0,"twenty-one to eleven in the morning")
  , (TimeOfDay 10 40 0,"twenty to eleven in the morning")
  , (TimeOfDay 10 41 0,"nineteen to eleven in the morning")
  , (TimeOfDay 10 42 0,"eighteen to eleven in the morning")
  , (TimeOfDay 10 43 0,"seventeen to eleven in the morning")
  , (TimeOfDay 10 44 0,"sixteen to eleven in the morning")
  , (TimeOfDay 10 45 0,"quarter to eleven in the morning")
  , (TimeOfDay 10 46 0,"fourteen to eleven in the morning")
  , (TimeOfDay 10 47 0,"thirteen to eleven in the morning")
  , (TimeOfDay 10 48 0,"twelve to eleven in the morning")
  , (TimeOfDay 10 49 0,"eleven to eleven in the morning")
  , (TimeOfDay 10 50 0,"ten to eleven in the morning")
  , (TimeOfDay 10 51 0,"nine to eleven in the morning")
  , (TimeOfDay 10 52 0,"eight to eleven in the morning")
  , (TimeOfDay 10 53 0,"seven to eleven in the morning")
  , (TimeOfDay 10 54 0,"six to eleven in the morning")
  , (TimeOfDay 10 55 0,"five to eleven in the morning")
  , (TimeOfDay 10 56 0,"four to eleven in the morning")
  , (TimeOfDay 10 57 0,"three to eleven in the morning")
  , (TimeOfDay 10 58 0,"two to eleven in the morning")
  , (TimeOfDay 10 59 0,"one to eleven in the morning")
  , (TimeOfDay 11 0 0,"eleven o'clock in the morning")
  , (TimeOfDay 11 1 0,"one past eleven in the morning")
  , (TimeOfDay 11 2 0,"two past eleven in the morning")
  , (TimeOfDay 11 3 0,"three past eleven in the morning")
  , (TimeOfDay 11 4 0,"four past eleven in the morning")
  , (TimeOfDay 11 5 0,"five past eleven in the morning")
  , (TimeOfDay 11 6 0,"six past eleven in the morning")
  , (TimeOfDay 11 7 0,"seven past eleven in the morning")
  , (TimeOfDay 11 8 0,"eight past eleven in the morning")
  , (TimeOfDay 11 9 0,"nine past eleven in the morning")
  , (TimeOfDay 11 10 0,"ten past eleven in the morning")
  , (TimeOfDay 11 11 0,"eleven past eleven in the morning")
  , (TimeOfDay 11 12 0,"twelve past eleven in the morning")
  , (TimeOfDay 11 13 0,"thirteen past eleven in the morning")
  , (TimeOfDay 11 14 0,"fourteen past eleven in the morning")
  , (TimeOfDay 11 15 0,"quarter past eleven in the morning")
  , (TimeOfDay 11 16 0,"sixteen past eleven in the morning")
  , (TimeOfDay 11 17 0,"seventeen past eleven in the morning")
  , (TimeOfDay 11 18 0,"eighteen past eleven in the morning")
  , (TimeOfDay 11 19 0,"nineteen past eleven in the morning")
  , (TimeOfDay 11 20 0,"twenty past eleven in the morning")
  , (TimeOfDay 11 21 0,"twenty-one past eleven in the morning")
  , (TimeOfDay 11 22 0,"twenty-two past eleven in the morning")
  , (TimeOfDay 11 23 0,"twenty-three past eleven in the morning")
  , (TimeOfDay 11 24 0,"twenty-four past eleven in the morning")
  , (TimeOfDay 11 25 0,"twenty-five past eleven in the morning")
  , (TimeOfDay 11 26 0,"twenty-six past eleven in the morning")
  , (TimeOfDay 11 27 0,"twenty-seven past eleven in the morning")
  , (TimeOfDay 11 28 0,"twenty-eight past eleven in the morning")
  , (TimeOfDay 11 29 0,"twenty-nine past eleven in the morning")
  , (TimeOfDay 11 30 0,"half past eleven in the morning")
  , (TimeOfDay 11 31 0,"twenty-nine to twelve in the morning")
  , (TimeOfDay 11 32 0,"twenty-eight to twelve in the morning")
  , (TimeOfDay 11 33 0,"twenty-seven to twelve in the morning")
  , (TimeOfDay 11 34 0,"twenty-six to twelve in the morning")
  , (TimeOfDay 11 35 0,"twenty-five to twelve in the morning")
  , (TimeOfDay 11 36 0,"twenty-four to twelve in the morning")
  , (TimeOfDay 11 37 0,"twenty-three to twelve in the morning")
  , (TimeOfDay 11 38 0,"twenty-two to twelve in the morning")
  , (TimeOfDay 11 39 0,"twenty-one to twelve in the morning")
  , (TimeOfDay 11 40 0,"twenty to twelve in the morning")
  , (TimeOfDay 11 41 0,"nineteen to twelve in the morning")
  , (TimeOfDay 11 42 0,"eighteen to twelve in the morning")
  , (TimeOfDay 11 43 0,"seventeen to twelve in the morning")
  , (TimeOfDay 11 44 0,"sixteen to twelve in the morning")
  , (TimeOfDay 11 45 0,"quarter to twelve in the morning")
  , (TimeOfDay 11 46 0,"fourteen to twelve in the morning")
  , (TimeOfDay 11 47 0,"thirteen to twelve in the morning")
  , (TimeOfDay 11 48 0,"twelve to twelve in the morning")
  , (TimeOfDay 11 49 0,"eleven to twelve in the morning")
  , (TimeOfDay 11 50 0,"ten to twelve in the morning")
  , (TimeOfDay 11 51 0,"nine to twelve in the morning")
  , (TimeOfDay 11 52 0,"eight to twelve in the morning")
  , (TimeOfDay 11 53 0,"seven to twelve in the morning")
  , (TimeOfDay 11 54 0,"six to twelve in the morning")
  , (TimeOfDay 11 55 0,"five to twelve in the morning")
  , (TimeOfDay 11 56 0,"four to twelve in the morning")
  , (TimeOfDay 11 57 0,"three to twelve in the morning")
  , (TimeOfDay 11 58 0,"two to twelve in the morning")
  , (TimeOfDay 11 59 0,"one to twelve in the morning")
  , (TimeOfDay 12 0 0,"twelve o'clock in the afternoon")
  , (TimeOfDay 12 1 0,"one past twelve in the afternoon")
  , (TimeOfDay 12 2 0,"two past twelve in the afternoon")
  , (TimeOfDay 12 3 0,"three past twelve in the afternoon")
  , (TimeOfDay 12 4 0,"four past twelve in the afternoon")
  , (TimeOfDay 12 5 0,"five past twelve in the afternoon")
  , (TimeOfDay 12 6 0,"six past twelve in the afternoon")
  , (TimeOfDay 12 7 0,"seven past twelve in the afternoon")
  , (TimeOfDay 12 8 0,"eight past twelve in the afternoon")
  , (TimeOfDay 12 9 0,"nine past twelve in the afternoon")
  , (TimeOfDay 12 10 0,"ten past twelve in the afternoon")
  , (TimeOfDay 12 11 0,"eleven past twelve in the afternoon")
  , (TimeOfDay 12 12 0,"twelve past twelve in the afternoon")
  , (TimeOfDay 12 13 0,"thirteen past twelve in the afternoon")
  , (TimeOfDay 12 14 0,"fourteen past twelve in the afternoon")
  , (TimeOfDay 12 15 0,"quarter past twelve in the afternoon")
  , (TimeOfDay 12 16 0,"sixteen past twelve in the afternoon")
  , (TimeOfDay 12 17 0,"seventeen past twelve in the afternoon")
  , (TimeOfDay 12 18 0,"eighteen past twelve in the afternoon")
  , (TimeOfDay 12 19 0,"nineteen past twelve in the afternoon")
  , (TimeOfDay 12 20 0,"twenty past twelve in the afternoon")
  , (TimeOfDay 12 21 0,"twenty-one past twelve in the afternoon")
  , (TimeOfDay 12 22 0,"twenty-two past twelve in the afternoon")
  , (TimeOfDay 12 23 0,"twenty-three past twelve in the afternoon")
  , (TimeOfDay 12 24 0,"twenty-four past twelve in the afternoon")
  , (TimeOfDay 12 25 0,"twenty-five past twelve in the afternoon")
  , (TimeOfDay 12 26 0,"twenty-six past twelve in the afternoon")
  , (TimeOfDay 12 27 0,"twenty-seven past twelve in the afternoon")
  , (TimeOfDay 12 28 0,"twenty-eight past twelve in the afternoon")
  , (TimeOfDay 12 29 0,"twenty-nine past twelve in the afternoon")
  , (TimeOfDay 12 30 0,"half past twelve in the afternoon")
  , (TimeOfDay 12 31 0,"twenty-nine to one in the afternoon")
  , (TimeOfDay 12 32 0,"twenty-eight to one in the afternoon")
  , (TimeOfDay 12 33 0,"twenty-seven to one in the afternoon")
  , (TimeOfDay 12 34 0,"twenty-six to one in the afternoon")
  , (TimeOfDay 12 35 0,"twenty-five to one in the afternoon")
  , (TimeOfDay 12 36 0,"twenty-four to one in the afternoon")
  , (TimeOfDay 12 37 0,"twenty-three to one in the afternoon")
  , (TimeOfDay 12 38 0,"twenty-two to one in the afternoon")
  , (TimeOfDay 12 39 0,"twenty-one to one in the afternoon")
  , (TimeOfDay 12 40 0,"twenty to one in the afternoon")
  , (TimeOfDay 12 41 0,"nineteen to one in the afternoon")
  , (TimeOfDay 12 42 0,"eighteen to one in the afternoon")
  , (TimeOfDay 12 43 0,"seventeen to one in the afternoon")
  , (TimeOfDay 12 44 0,"sixteen to one in the afternoon")
  , (TimeOfDay 12 45 0,"quarter to one in the afternoon")
  , (TimeOfDay 12 46 0,"fourteen to one in the afternoon")
  , (TimeOfDay 12 47 0,"thirteen to one in the afternoon")
  , (TimeOfDay 12 48 0,"twelve to one in the afternoon")
  , (TimeOfDay 12 49 0,"eleven to one in the afternoon")
  , (TimeOfDay 12 50 0,"ten to one in the afternoon")
  , (TimeOfDay 12 51 0,"nine to one in the afternoon")
  , (TimeOfDay 12 52 0,"eight to one in the afternoon")
  , (TimeOfDay 12 53 0,"seven to one in the afternoon")
  , (TimeOfDay 12 54 0,"six to one in the afternoon")
  , (TimeOfDay 12 55 0,"five to one in the afternoon")
  , (TimeOfDay 12 56 0,"four to one in the afternoon")
  , (TimeOfDay 12 57 0,"three to one in the afternoon")
  , (TimeOfDay 12 58 0,"two to one in the afternoon")
  , (TimeOfDay 12 59 0,"one to one in the afternoon")
  , (TimeOfDay 13 0 0,"one o'clock in the afternoon")
  , (TimeOfDay 13 1 0,"one past one in the afternoon")
  , (TimeOfDay 13 2 0,"two past one in the afternoon")
  , (TimeOfDay 13 3 0,"three past one in the afternoon")
  , (TimeOfDay 13 4 0,"four past one in the afternoon")
  , (TimeOfDay 13 5 0,"five past one in the afternoon")
  , (TimeOfDay 13 6 0,"six past one in the afternoon")
  , (TimeOfDay 13 7 0,"seven past one in the afternoon")
  , (TimeOfDay 13 8 0,"eight past one in the afternoon")
  , (TimeOfDay 13 9 0,"nine past one in the afternoon")
  , (TimeOfDay 13 10 0,"ten past one in the afternoon")
  , (TimeOfDay 13 11 0,"eleven past one in the afternoon")
  , (TimeOfDay 13 12 0,"twelve past one in the afternoon")
  , (TimeOfDay 13 13 0,"thirteen past one in the afternoon")
  , (TimeOfDay 13 14 0,"fourteen past one in the afternoon")
  , (TimeOfDay 13 15 0,"quarter past one in the afternoon")
  , (TimeOfDay 13 16 0,"sixteen past one in the afternoon")
  , (TimeOfDay 13 17 0,"seventeen past one in the afternoon")
  , (TimeOfDay 13 18 0,"eighteen past one in the afternoon")
  , (TimeOfDay 13 19 0,"nineteen past one in the afternoon")
  , (TimeOfDay 13 20 0,"twenty past one in the afternoon")
  , (TimeOfDay 13 21 0,"twenty-one past one in the afternoon")
  , (TimeOfDay 13 22 0,"twenty-two past one in the afternoon")
  , (TimeOfDay 13 23 0,"twenty-three past one in the afternoon")
  , (TimeOfDay 13 24 0,"twenty-four past one in the afternoon")
  , (TimeOfDay 13 25 0,"twenty-five past one in the afternoon")
  , (TimeOfDay 13 26 0,"twenty-six past one in the afternoon")
  , (TimeOfDay 13 27 0,"twenty-seven past one in the afternoon")
  , (TimeOfDay 13 28 0,"twenty-eight past one in the afternoon")
  , (TimeOfDay 13 29 0,"twenty-nine past one in the afternoon")
  , (TimeOfDay 13 30 0,"half past one in the afternoon")
  , (TimeOfDay 13 31 0,"twenty-nine to two in the afternoon")
  , (TimeOfDay 13 32 0,"twenty-eight to two in the afternoon")
  , (TimeOfDay 13 33 0,"twenty-seven to two in the afternoon")
  , (TimeOfDay 13 34 0,"twenty-six to two in the afternoon")
  , (TimeOfDay 13 35 0,"twenty-five to two in the afternoon")
  , (TimeOfDay 13 36 0,"twenty-four to two in the afternoon")
  , (TimeOfDay 13 37 0,"twenty-three to two in the afternoon")
  , (TimeOfDay 13 38 0,"twenty-two to two in the afternoon")
  , (TimeOfDay 13 39 0,"twenty-one to two in the afternoon")
  , (TimeOfDay 13 40 0,"twenty to two in the afternoon")
  , (TimeOfDay 13 41 0,"nineteen to two in the afternoon")
  , (TimeOfDay 13 42 0,"eighteen to two in the afternoon")
  , (TimeOfDay 13 43 0,"seventeen to two in the afternoon")
  , (TimeOfDay 13 44 0,"sixteen to two in the afternoon")
  , (TimeOfDay 13 45 0,"quarter to two in the afternoon")
  , (TimeOfDay 13 46 0,"fourteen to two in the afternoon")
  , (TimeOfDay 13 47 0,"thirteen to two in the afternoon")
  , (TimeOfDay 13 48 0,"twelve to two in the afternoon")
  , (TimeOfDay 13 49 0,"eleven to two in the afternoon")
  , (TimeOfDay 13 50 0,"ten to two in the afternoon")
  , (TimeOfDay 13 51 0,"nine to two in the afternoon")
  , (TimeOfDay 13 52 0,"eight to two in the afternoon")
  , (TimeOfDay 13 53 0,"seven to two in the afternoon")
  , (TimeOfDay 13 54 0,"six to two in the afternoon")
  , (TimeOfDay 13 55 0,"five to two in the afternoon")
  , (TimeOfDay 13 56 0,"four to two in the afternoon")
  , (TimeOfDay 13 57 0,"three to two in the afternoon")
  , (TimeOfDay 13 58 0,"two to two in the afternoon")
  , (TimeOfDay 13 59 0,"one to two in the afternoon")
  , (TimeOfDay 14 0 0,"two o'clock in the afternoon")
  , (TimeOfDay 14 1 0,"one past two in the afternoon")
  , (TimeOfDay 14 2 0,"two past two in the afternoon")
  , (TimeOfDay 14 3 0,"three past two in the afternoon")
  , (TimeOfDay 14 4 0,"four past two in the afternoon")
  , (TimeOfDay 14 5 0,"five past two in the afternoon")
  , (TimeOfDay 14 6 0,"six past two in the afternoon")
  , (TimeOfDay 14 7 0,"seven past two in the afternoon")
  , (TimeOfDay 14 8 0,"eight past two in the afternoon")
  , (TimeOfDay 14 9 0,"nine past two in the afternoon")
  , (TimeOfDay 14 10 0,"ten past two in the afternoon")
  , (TimeOfDay 14 11 0,"eleven past two in the afternoon")
  , (TimeOfDay 14 12 0,"twelve past two in the afternoon")
  , (TimeOfDay 14 13 0,"thirteen past two in the afternoon")
  , (TimeOfDay 14 14 0,"fourteen past two in the afternoon")
  , (TimeOfDay 14 15 0,"quarter past two in the afternoon")
  , (TimeOfDay 14 16 0,"sixteen past two in the afternoon")
  , (TimeOfDay 14 17 0,"seventeen past two in the afternoon")
  , (TimeOfDay 14 18 0,"eighteen past two in the afternoon")
  , (TimeOfDay 14 19 0,"nineteen past two in the afternoon")
  , (TimeOfDay 14 20 0,"twenty past two in the afternoon")
  , (TimeOfDay 14 21 0,"twenty-one past two in the afternoon")
  , (TimeOfDay 14 22 0,"twenty-two past two in the afternoon")
  , (TimeOfDay 14 23 0,"twenty-three past two in the afternoon")
  , (TimeOfDay 14 24 0,"twenty-four past two in the afternoon")
  , (TimeOfDay 14 25 0,"twenty-five past two in the afternoon")
  , (TimeOfDay 14 26 0,"twenty-six past two in the afternoon")
  , (TimeOfDay 14 27 0,"twenty-seven past two in the afternoon")
  , (TimeOfDay 14 28 0,"twenty-eight past two in the afternoon")
  , (TimeOfDay 14 29 0,"twenty-nine past two in the afternoon")
  , (TimeOfDay 14 30 0,"half past two in the afternoon")
  , (TimeOfDay 14 31 0,"twenty-nine to three in the afternoon")
  , (TimeOfDay 14 32 0,"twenty-eight to three in the afternoon")
  , (TimeOfDay 14 33 0,"twenty-seven to three in the afternoon")
  , (TimeOfDay 14 34 0,"twenty-six to three in the afternoon")
  , (TimeOfDay 14 35 0,"twenty-five to three in the afternoon")
  , (TimeOfDay 14 36 0,"twenty-four to three in the afternoon")
  , (TimeOfDay 14 37 0,"twenty-three to three in the afternoon")
  , (TimeOfDay 14 38 0,"twenty-two to three in the afternoon")
  , (TimeOfDay 14 39 0,"twenty-one to three in the afternoon")
  , (TimeOfDay 14 40 0,"twenty to three in the afternoon")
  , (TimeOfDay 14 41 0,"nineteen to three in the afternoon")
  , (TimeOfDay 14 42 0,"eighteen to three in the afternoon")
  , (TimeOfDay 14 43 0,"seventeen to three in the afternoon")
  , (TimeOfDay 14 44 0,"sixteen to three in the afternoon")
  , (TimeOfDay 14 45 0,"quarter to three in the afternoon")
  , (TimeOfDay 14 46 0,"fourteen to three in the afternoon")
  , (TimeOfDay 14 47 0,"thirteen to three in the afternoon")
  , (TimeOfDay 14 48 0,"twelve to three in the afternoon")
  , (TimeOfDay 14 49 0,"eleven to three in the afternoon")
  , (TimeOfDay 14 50 0,"ten to three in the afternoon")
  , (TimeOfDay 14 51 0,"nine to three in the afternoon")
  , (TimeOfDay 14 52 0,"eight to three in the afternoon")
  , (TimeOfDay 14 53 0,"seven to three in the afternoon")
  , (TimeOfDay 14 54 0,"six to three in the afternoon")
  , (TimeOfDay 14 55 0,"five to three in the afternoon")
  , (TimeOfDay 14 56 0,"four to three in the afternoon")
  , (TimeOfDay 14 57 0,"three to three in the afternoon")
  , (TimeOfDay 14 58 0,"two to three in the afternoon")
  , (TimeOfDay 14 59 0,"one to three in the afternoon")
  , (TimeOfDay 15 0 0,"three o'clock in the afternoon")
  , (TimeOfDay 15 1 0,"one past three in the afternoon")
  , (TimeOfDay 15 2 0,"two past three in the afternoon")
  , (TimeOfDay 15 3 0,"three past three in the afternoon")
  , (TimeOfDay 15 4 0,"four past three in the afternoon")
  , (TimeOfDay 15 5 0,"five past three in the afternoon")
  , (TimeOfDay 15 6 0,"six past three in the afternoon")
  , (TimeOfDay 15 7 0,"seven past three in the afternoon")
  , (TimeOfDay 15 8 0,"eight past three in the afternoon")
  , (TimeOfDay 15 9 0,"nine past three in the afternoon")
  , (TimeOfDay 15 10 0,"ten past three in the afternoon")
  , (TimeOfDay 15 11 0,"eleven past three in the afternoon")
  , (TimeOfDay 15 12 0,"twelve past three in the afternoon")
  , (TimeOfDay 15 13 0,"thirteen past three in the afternoon")
  , (TimeOfDay 15 14 0,"fourteen past three in the afternoon")
  , (TimeOfDay 15 15 0,"quarter past three in the afternoon")
  , (TimeOfDay 15 16 0,"sixteen past three in the afternoon")
  , (TimeOfDay 15 17 0,"seventeen past three in the afternoon")
  , (TimeOfDay 15 18 0,"eighteen past three in the afternoon")
  , (TimeOfDay 15 19 0,"nineteen past three in the afternoon")
  , (TimeOfDay 15 20 0,"twenty past three in the afternoon")
  , (TimeOfDay 15 21 0,"twenty-one past three in the afternoon")
  , (TimeOfDay 15 22 0,"twenty-two past three in the afternoon")
  , (TimeOfDay 15 23 0,"twenty-three past three in the afternoon")
  , (TimeOfDay 15 24 0,"twenty-four past three in the afternoon")
  , (TimeOfDay 15 25 0,"twenty-five past three in the afternoon")
  , (TimeOfDay 15 26 0,"twenty-six past three in the afternoon")
  , (TimeOfDay 15 27 0,"twenty-seven past three in the afternoon")
  , (TimeOfDay 15 28 0,"twenty-eight past three in the afternoon")
  , (TimeOfDay 15 29 0,"twenty-nine past three in the afternoon")
  , (TimeOfDay 15 30 0,"half past three in the afternoon")
  , (TimeOfDay 15 31 0,"twenty-nine to four in the afternoon")
  , (TimeOfDay 15 32 0,"twenty-eight to four in the afternoon")
  , (TimeOfDay 15 33 0,"twenty-seven to four in the afternoon")
  , (TimeOfDay 15 34 0,"twenty-six to four in the afternoon")
  , (TimeOfDay 15 35 0,"twenty-five to four in the afternoon")
  , (TimeOfDay 15 36 0,"twenty-four to four in the afternoon")
  , (TimeOfDay 15 37 0,"twenty-three to four in the afternoon")
  , (TimeOfDay 15 38 0,"twenty-two to four in the afternoon")
  , (TimeOfDay 15 39 0,"twenty-one to four in the afternoon")
  , (TimeOfDay 15 40 0,"twenty to four in the afternoon")
  , (TimeOfDay 15 41 0,"nineteen to four in the afternoon")
  , (TimeOfDay 15 42 0,"eighteen to four in the afternoon")
  , (TimeOfDay 15 43 0,"seventeen to four in the afternoon")
  , (TimeOfDay 15 44 0,"sixteen to four in the afternoon")
  , (TimeOfDay 15 45 0,"quarter to four in the afternoon")
  , (TimeOfDay 15 46 0,"fourteen to four in the afternoon")
  , (TimeOfDay 15 47 0,"thirteen to four in the afternoon")
  , (TimeOfDay 15 48 0,"twelve to four in the afternoon")
  , (TimeOfDay 15 49 0,"eleven to four in the afternoon")
  , (TimeOfDay 15 50 0,"ten to four in the afternoon")
  , (TimeOfDay 15 51 0,"nine to four in the afternoon")
  , (TimeOfDay 15 52 0,"eight to four in the afternoon")
  , (TimeOfDay 15 53 0,"seven to four in the afternoon")
  , (TimeOfDay 15 54 0,"six to four in the afternoon")
  , (TimeOfDay 15 55 0,"five to four in the afternoon")
  , (TimeOfDay 15 56 0,"four to four in the afternoon")
  , (TimeOfDay 15 57 0,"three to four in the afternoon")
  , (TimeOfDay 15 58 0,"two to four in the afternoon")
  , (TimeOfDay 15 59 0,"one to four in the afternoon")
  , (TimeOfDay 16 0 0,"four o'clock in the afternoon")
  , (TimeOfDay 16 1 0,"one past four in the afternoon")
  , (TimeOfDay 16 2 0,"two past four in the afternoon")
  , (TimeOfDay 16 3 0,"three past four in the afternoon")
  , (TimeOfDay 16 4 0,"four past four in the afternoon")
  , (TimeOfDay 16 5 0,"five past four in the afternoon")
  , (TimeOfDay 16 6 0,"six past four in the afternoon")
  , (TimeOfDay 16 7 0,"seven past four in the afternoon")
  , (TimeOfDay 16 8 0,"eight past four in the afternoon")
  , (TimeOfDay 16 9 0,"nine past four in the afternoon")
  , (TimeOfDay 16 10 0,"ten past four in the afternoon")
  , (TimeOfDay 16 11 0,"eleven past four in the afternoon")
  , (TimeOfDay 16 12 0,"twelve past four in the afternoon")
  , (TimeOfDay 16 13 0,"thirteen past four in the afternoon")
  , (TimeOfDay 16 14 0,"fourteen past four in the afternoon")
  , (TimeOfDay 16 15 0,"quarter past four in the afternoon")
  , (TimeOfDay 16 16 0,"sixteen past four in the afternoon")
  , (TimeOfDay 16 17 0,"seventeen past four in the afternoon")
  , (TimeOfDay 16 18 0,"eighteen past four in the afternoon")
  , (TimeOfDay 16 19 0,"nineteen past four in the afternoon")
  , (TimeOfDay 16 20 0,"twenty past four in the afternoon")
  , (TimeOfDay 16 21 0,"twenty-one past four in the afternoon")
  , (TimeOfDay 16 22 0,"twenty-two past four in the afternoon")
  , (TimeOfDay 16 23 0,"twenty-three past four in the afternoon")
  , (TimeOfDay 16 24 0,"twenty-four past four in the afternoon")
  , (TimeOfDay 16 25 0,"twenty-five past four in the afternoon")
  , (TimeOfDay 16 26 0,"twenty-six past four in the afternoon")
  , (TimeOfDay 16 27 0,"twenty-seven past four in the afternoon")
  , (TimeOfDay 16 28 0,"twenty-eight past four in the afternoon")
  , (TimeOfDay 16 29 0,"twenty-nine past four in the afternoon")
  , (TimeOfDay 16 30 0,"half past four in the afternoon")
  , (TimeOfDay 16 31 0,"twenty-nine to five in the afternoon")
  , (TimeOfDay 16 32 0,"twenty-eight to five in the afternoon")
  , (TimeOfDay 16 33 0,"twenty-seven to five in the afternoon")
  , (TimeOfDay 16 34 0,"twenty-six to five in the afternoon")
  , (TimeOfDay 16 35 0,"twenty-five to five in the afternoon")
  , (TimeOfDay 16 36 0,"twenty-four to five in the afternoon")
  , (TimeOfDay 16 37 0,"twenty-three to five in the afternoon")
  , (TimeOfDay 16 38 0,"twenty-two to five in the afternoon")
  , (TimeOfDay 16 39 0,"twenty-one to five in the afternoon")
  , (TimeOfDay 16 40 0,"twenty to five in the afternoon")
  , (TimeOfDay 16 41 0,"nineteen to five in the afternoon")
  , (TimeOfDay 16 42 0,"eighteen to five in the afternoon")
  , (TimeOfDay 16 43 0,"seventeen to five in the afternoon")
  , (TimeOfDay 16 44 0,"sixteen to five in the afternoon")
  , (TimeOfDay 16 45 0,"quarter to five in the afternoon")
  , (TimeOfDay 16 46 0,"fourteen to five in the afternoon")
  , (TimeOfDay 16 47 0,"thirteen to five in the afternoon")
  , (TimeOfDay 16 48 0,"twelve to five in the afternoon")
  , (TimeOfDay 16 49 0,"eleven to five in the afternoon")
  , (TimeOfDay 16 50 0,"ten to five in the afternoon")
  , (TimeOfDay 16 51 0,"nine to five in the afternoon")
  , (TimeOfDay 16 52 0,"eight to five in the afternoon")
  , (TimeOfDay 16 53 0,"seven to five in the afternoon")
  , (TimeOfDay 16 54 0,"six to five in the afternoon")
  , (TimeOfDay 16 55 0,"five to five in the afternoon")
  , (TimeOfDay 16 56 0,"four to five in the afternoon")
  , (TimeOfDay 16 57 0,"three to five in the afternoon")
  , (TimeOfDay 16 58 0,"two to five in the afternoon")
  , (TimeOfDay 16 59 0,"one to five in the afternoon")
  , (TimeOfDay 17 0 0,"five o'clock in the afternoon")
  , (TimeOfDay 17 1 0,"one past five in the afternoon")
  , (TimeOfDay 17 2 0,"two past five in the afternoon")
  , (TimeOfDay 17 3 0,"three past five in the afternoon")
  , (TimeOfDay 17 4 0,"four past five in the afternoon")
  , (TimeOfDay 17 5 0,"five past five in the afternoon")
  , (TimeOfDay 17 6 0,"six past five in the afternoon")
  , (TimeOfDay 17 7 0,"seven past five in the afternoon")
  , (TimeOfDay 17 8 0,"eight past five in the afternoon")
  , (TimeOfDay 17 9 0,"nine past five in the afternoon")
  , (TimeOfDay 17 10 0,"ten past five in the afternoon")
  , (TimeOfDay 17 11 0,"eleven past five in the afternoon")
  , (TimeOfDay 17 12 0,"twelve past five in the afternoon")
  , (TimeOfDay 17 13 0,"thirteen past five in the afternoon")
  , (TimeOfDay 17 14 0,"fourteen past five in the afternoon")
  , (TimeOfDay 17 15 0,"quarter past five in the afternoon")
  , (TimeOfDay 17 16 0,"sixteen past five in the afternoon")
  , (TimeOfDay 17 17 0,"seventeen past five in the afternoon")
  , (TimeOfDay 17 18 0,"eighteen past five in the afternoon")
  , (TimeOfDay 17 19 0,"nineteen past five in the afternoon")
  , (TimeOfDay 17 20 0,"twenty past five in the afternoon")
  , (TimeOfDay 17 21 0,"twenty-one past five in the afternoon")
  , (TimeOfDay 17 22 0,"twenty-two past five in the afternoon")
  , (TimeOfDay 17 23 0,"twenty-three past five in the afternoon")
  , (TimeOfDay 17 24 0,"twenty-four past five in the afternoon")
  , (TimeOfDay 17 25 0,"twenty-five past five in the afternoon")
  , (TimeOfDay 17 26 0,"twenty-six past five in the afternoon")
  , (TimeOfDay 17 27 0,"twenty-seven past five in the afternoon")
  , (TimeOfDay 17 28 0,"twenty-eight past five in the afternoon")
  , (TimeOfDay 17 29 0,"twenty-nine past five in the afternoon")
  , (TimeOfDay 17 30 0,"half past five in the afternoon")
  , (TimeOfDay 17 31 0,"twenty-nine to six in the afternoon")
  , (TimeOfDay 17 32 0,"twenty-eight to six in the afternoon")
  , (TimeOfDay 17 33 0,"twenty-seven to six in the afternoon")
  , (TimeOfDay 17 34 0,"twenty-six to six in the afternoon")
  , (TimeOfDay 17 35 0,"twenty-five to six in the afternoon")
  , (TimeOfDay 17 36 0,"twenty-four to six in the afternoon")
  , (TimeOfDay 17 37 0,"twenty-three to six in the afternoon")
  , (TimeOfDay 17 38 0,"twenty-two to six in the afternoon")
  , (TimeOfDay 17 39 0,"twenty-one to six in the afternoon")
  , (TimeOfDay 17 40 0,"twenty to six in the afternoon")
  , (TimeOfDay 17 41 0,"nineteen to six in the afternoon")
  , (TimeOfDay 17 42 0,"eighteen to six in the afternoon")
  , (TimeOfDay 17 43 0,"seventeen to six in the afternoon")
  , (TimeOfDay 17 44 0,"sixteen to six in the afternoon")
  , (TimeOfDay 17 45 0,"quarter to six in the afternoon")
  , (TimeOfDay 17 46 0,"fourteen to six in the afternoon")
  , (TimeOfDay 17 47 0,"thirteen to six in the afternoon")
  , (TimeOfDay 17 48 0,"twelve to six in the afternoon")
  , (TimeOfDay 17 49 0,"eleven to six in the afternoon")
  , (TimeOfDay 17 50 0,"ten to six in the afternoon")
  , (TimeOfDay 17 51 0,"nine to six in the afternoon")
  , (TimeOfDay 17 52 0,"eight to six in the afternoon")
  , (TimeOfDay 17 53 0,"seven to six in the afternoon")
  , (TimeOfDay 17 54 0,"six to six in the afternoon")
  , (TimeOfDay 17 55 0,"five to six in the afternoon")
  , (TimeOfDay 17 56 0,"four to six in the afternoon")
  , (TimeOfDay 17 57 0,"three to six in the afternoon")
  , (TimeOfDay 17 58 0,"two to six in the afternoon")
  , (TimeOfDay 17 59 0,"one to six in the afternoon")
  , (TimeOfDay 18 0 0,"six o'clock in the evening")
  , (TimeOfDay 18 1 0,"one past six in the evening")
  , (TimeOfDay 18 2 0,"two past six in the evening")
  , (TimeOfDay 18 3 0,"three past six in the evening")
  , (TimeOfDay 18 4 0,"four past six in the evening")
  , (TimeOfDay 18 5 0,"five past six in the evening")
  , (TimeOfDay 18 6 0,"six past six in the evening")
  , (TimeOfDay 18 7 0,"seven past six in the evening")
  , (TimeOfDay 18 8 0,"eight past six in the evening")
  , (TimeOfDay 18 9 0,"nine past six in the evening")
  , (TimeOfDay 18 10 0,"ten past six in the evening")
  , (TimeOfDay 18 11 0,"eleven past six in the evening")
  , (TimeOfDay 18 12 0,"twelve past six in the evening")
  , (TimeOfDay 18 13 0,"thirteen past six in the evening")
  , (TimeOfDay 18 14 0,"fourteen past six in the evening")
  , (TimeOfDay 18 15 0,"quarter past six in the evening")
  , (TimeOfDay 18 16 0,"sixteen past six in the evening")
  , (TimeOfDay 18 17 0,"seventeen past six in the evening")
  , (TimeOfDay 18 18 0,"eighteen past six in the evening")
  , (TimeOfDay 18 19 0,"nineteen past six in the evening")
  , (TimeOfDay 18 20 0,"twenty past six in the evening")
  , (TimeOfDay 18 21 0,"twenty-one past six in the evening")
  , (TimeOfDay 18 22 0,"twenty-two past six in the evening")
  , (TimeOfDay 18 23 0,"twenty-three past six in the evening")
  , (TimeOfDay 18 24 0,"twenty-four past six in the evening")
  , (TimeOfDay 18 25 0,"twenty-five past six in the evening")
  , (TimeOfDay 18 26 0,"twenty-six past six in the evening")
  , (TimeOfDay 18 27 0,"twenty-seven past six in the evening")
  , (TimeOfDay 18 28 0,"twenty-eight past six in the evening")
  , (TimeOfDay 18 29 0,"twenty-nine past six in the evening")
  , (TimeOfDay 18 30 0,"half past six in the evening")
  , (TimeOfDay 18 31 0,"twenty-nine to seven in the evening")
  , (TimeOfDay 18 32 0,"twenty-eight to seven in the evening")
  , (TimeOfDay 18 33 0,"twenty-seven to seven in the evening")
  , (TimeOfDay 18 34 0,"twenty-six to seven in the evening")
  , (TimeOfDay 18 35 0,"twenty-five to seven in the evening")
  , (TimeOfDay 18 36 0,"twenty-four to seven in the evening")
  , (TimeOfDay 18 37 0,"twenty-three to seven in the evening")
  , (TimeOfDay 18 38 0,"twenty-two to seven in the evening")
  , (TimeOfDay 18 39 0,"twenty-one to seven in the evening")
  , (TimeOfDay 18 40 0,"twenty to seven in the evening")
  , (TimeOfDay 18 41 0,"nineteen to seven in the evening")
  , (TimeOfDay 18 42 0,"eighteen to seven in the evening")
  , (TimeOfDay 18 43 0,"seventeen to seven in the evening")
  , (TimeOfDay 18 44 0,"sixteen to seven in the evening")
  , (TimeOfDay 18 45 0,"quarter to seven in the evening")
  , (TimeOfDay 18 46 0,"fourteen to seven in the evening")
  , (TimeOfDay 18 47 0,"thirteen to seven in the evening")
  , (TimeOfDay 18 48 0,"twelve to seven in the evening")
  , (TimeOfDay 18 49 0,"eleven to seven in the evening")
  , (TimeOfDay 18 50 0,"ten to seven in the evening")
  , (TimeOfDay 18 51 0,"nine to seven in the evening")
  , (TimeOfDay 18 52 0,"eight to seven in the evening")
  , (TimeOfDay 18 53 0,"seven to seven in the evening")
  , (TimeOfDay 18 54 0,"six to seven in the evening")
  , (TimeOfDay 18 55 0,"five to seven in the evening")
  , (TimeOfDay 18 56 0,"four to seven in the evening")
  , (TimeOfDay 18 57 0,"three to seven in the evening")
  , (TimeOfDay 18 58 0,"two to seven in the evening")
  , (TimeOfDay 18 59 0,"one to seven in the evening")
  , (TimeOfDay 19 0 0,"seven o'clock in the evening")
  , (TimeOfDay 19 1 0,"one past seven in the evening")
  , (TimeOfDay 19 2 0,"two past seven in the evening")
  , (TimeOfDay 19 3 0,"three past seven in the evening")
  , (TimeOfDay 19 4 0,"four past seven in the evening")
  , (TimeOfDay 19 5 0,"five past seven in the evening")
  , (TimeOfDay 19 6 0,"six past seven in the evening")
  , (TimeOfDay 19 7 0,"seven past seven in the evening")
  , (TimeOfDay 19 8 0,"eight past seven in the evening")
  , (TimeOfDay 19 9 0,"nine past seven in the evening")
  , (TimeOfDay 19 10 0,"ten past seven in the evening")
  , (TimeOfDay 19 11 0,"eleven past seven in the evening")
  , (TimeOfDay 19 12 0,"twelve past seven in the evening")
  , (TimeOfDay 19 13 0,"thirteen past seven in the evening")
  , (TimeOfDay 19 14 0,"fourteen past seven in the evening")
  , (TimeOfDay 19 15 0,"quarter past seven in the evening")
  , (TimeOfDay 19 16 0,"sixteen past seven in the evening")
  , (TimeOfDay 19 17 0,"seventeen past seven in the evening")
  , (TimeOfDay 19 18 0,"eighteen past seven in the evening")
  , (TimeOfDay 19 19 0,"nineteen past seven in the evening")
  , (TimeOfDay 19 20 0,"twenty past seven in the evening")
  , (TimeOfDay 19 21 0,"twenty-one past seven in the evening")
  , (TimeOfDay 19 22 0,"twenty-two past seven in the evening")
  , (TimeOfDay 19 23 0,"twenty-three past seven in the evening")
  , (TimeOfDay 19 24 0,"twenty-four past seven in the evening")
  , (TimeOfDay 19 25 0,"twenty-five past seven in the evening")
  , (TimeOfDay 19 26 0,"twenty-six past seven in the evening")
  , (TimeOfDay 19 27 0,"twenty-seven past seven in the evening")
  , (TimeOfDay 19 28 0,"twenty-eight past seven in the evening")
  , (TimeOfDay 19 29 0,"twenty-nine past seven in the evening")
  , (TimeOfDay 19 30 0,"half past seven in the evening")
  , (TimeOfDay 19 31 0,"twenty-nine to eight in the evening")
  , (TimeOfDay 19 32 0,"twenty-eight to eight in the evening")
  , (TimeOfDay 19 33 0,"twenty-seven to eight in the evening")
  , (TimeOfDay 19 34 0,"twenty-six to eight in the evening")
  , (TimeOfDay 19 35 0,"twenty-five to eight in the evening")
  , (TimeOfDay 19 36 0,"twenty-four to eight in the evening")
  , (TimeOfDay 19 37 0,"twenty-three to eight in the evening")
  , (TimeOfDay 19 38 0,"twenty-two to eight in the evening")
  , (TimeOfDay 19 39 0,"twenty-one to eight in the evening")
  , (TimeOfDay 19 40 0,"twenty to eight in the evening")
  , (TimeOfDay 19 41 0,"nineteen to eight in the evening")
  , (TimeOfDay 19 42 0,"eighteen to eight in the evening")
  , (TimeOfDay 19 43 0,"seventeen to eight in the evening")
  , (TimeOfDay 19 44 0,"sixteen to eight in the evening")
  , (TimeOfDay 19 45 0,"quarter to eight in the evening")
  , (TimeOfDay 19 46 0,"fourteen to eight in the evening")
  , (TimeOfDay 19 47 0,"thirteen to eight in the evening")
  , (TimeOfDay 19 48 0,"twelve to eight in the evening")
  , (TimeOfDay 19 49 0,"eleven to eight in the evening")
  , (TimeOfDay 19 50 0,"ten to eight in the evening")
  , (TimeOfDay 19 51 0,"nine to eight in the evening")
  , (TimeOfDay 19 52 0,"eight to eight in the evening")
  , (TimeOfDay 19 53 0,"seven to eight in the evening")
  , (TimeOfDay 19 54 0,"six to eight in the evening")
  , (TimeOfDay 19 55 0,"five to eight in the evening")
  , (TimeOfDay 19 56 0,"four to eight in the evening")
  , (TimeOfDay 19 57 0,"three to eight in the evening")
  , (TimeOfDay 19 58 0,"two to eight in the evening")
  , (TimeOfDay 19 59 0,"one to eight in the evening")
  , (TimeOfDay 20 0 0,"eight o'clock in the evening")
  , (TimeOfDay 20 1 0,"one past eight in the evening")
  , (TimeOfDay 20 2 0,"two past eight in the evening")
  , (TimeOfDay 20 3 0,"three past eight in the evening")
  , (TimeOfDay 20 4 0,"four past eight in the evening")
  , (TimeOfDay 20 5 0,"five past eight in the evening")
  , (TimeOfDay 20 6 0,"six past eight in the evening")
  , (TimeOfDay 20 7 0,"seven past eight in the evening")
  , (TimeOfDay 20 8 0,"eight past eight in the evening")
  , (TimeOfDay 20 9 0,"nine past eight in the evening")
  , (TimeOfDay 20 10 0,"ten past eight in the evening")
  , (TimeOfDay 20 11 0,"eleven past eight in the evening")
  , (TimeOfDay 20 12 0,"twelve past eight in the evening")
  , (TimeOfDay 20 13 0,"thirteen past eight in the evening")
  , (TimeOfDay 20 14 0,"fourteen past eight in the evening")
  , (TimeOfDay 20 15 0,"quarter past eight in the evening")
  , (TimeOfDay 20 16 0,"sixteen past eight in the evening")
  , (TimeOfDay 20 17 0,"seventeen past eight in the evening")
  , (TimeOfDay 20 18 0,"eighteen past eight in the evening")
  , (TimeOfDay 20 19 0,"nineteen past eight in the evening")
  , (TimeOfDay 20 20 0,"twenty past eight in the evening")
  , (TimeOfDay 20 21 0,"twenty-one past eight in the evening")
  , (TimeOfDay 20 22 0,"twenty-two past eight in the evening")
  , (TimeOfDay 20 23 0,"twenty-three past eight in the evening")
  , (TimeOfDay 20 24 0,"twenty-four past eight in the evening")
  , (TimeOfDay 20 25 0,"twenty-five past eight in the evening")
  , (TimeOfDay 20 26 0,"twenty-six past eight in the evening")
  , (TimeOfDay 20 27 0,"twenty-seven past eight in the evening")
  , (TimeOfDay 20 28 0,"twenty-eight past eight in the evening")
  , (TimeOfDay 20 29 0,"twenty-nine past eight in the evening")
  , (TimeOfDay 20 30 0,"half past eight in the evening")
  , (TimeOfDay 20 31 0,"twenty-nine to nine in the evening")
  , (TimeOfDay 20 32 0,"twenty-eight to nine in the evening")
  , (TimeOfDay 20 33 0,"twenty-seven to nine in the evening")
  , (TimeOfDay 20 34 0,"twenty-six to nine in the evening")
  , (TimeOfDay 20 35 0,"twenty-five to nine in the evening")
  , (TimeOfDay 20 36 0,"twenty-four to nine in the evening")
  , (TimeOfDay 20 37 0,"twenty-three to nine in the evening")
  , (TimeOfDay 20 38 0,"twenty-two to nine in the evening")
  , (TimeOfDay 20 39 0,"twenty-one to nine in the evening")
  , (TimeOfDay 20 40 0,"twenty to nine in the evening")
  , (TimeOfDay 20 41 0,"nineteen to nine in the evening")
  , (TimeOfDay 20 42 0,"eighteen to nine in the evening")
  , (TimeOfDay 20 43 0,"seventeen to nine in the evening")
  , (TimeOfDay 20 44 0,"sixteen to nine in the evening")
  , (TimeOfDay 20 45 0,"quarter to nine in the evening")
  , (TimeOfDay 20 46 0,"fourteen to nine in the evening")
  , (TimeOfDay 20 47 0,"thirteen to nine in the evening")
  , (TimeOfDay 20 48 0,"twelve to nine in the evening")
  , (TimeOfDay 20 49 0,"eleven to nine in the evening")
  , (TimeOfDay 20 50 0,"ten to nine in the evening")
  , (TimeOfDay 20 51 0,"nine to nine in the evening")
  , (TimeOfDay 20 52 0,"eight to nine in the evening")
  , (TimeOfDay 20 53 0,"seven to nine in the evening")
  , (TimeOfDay 20 54 0,"six to nine in the evening")
  , (TimeOfDay 20 55 0,"five to nine in the evening")
  , (TimeOfDay 20 56 0,"four to nine in the evening")
  , (TimeOfDay 20 57 0,"three to nine in the evening")
  , (TimeOfDay 20 58 0,"two to nine in the evening")
  , (TimeOfDay 20 59 0,"one to nine in the evening")
  , (TimeOfDay 21 0 0,"nine o'clock in the evening")
  , (TimeOfDay 21 1 0,"one past nine in the evening")
  , (TimeOfDay 21 2 0,"two past nine in the evening")
  , (TimeOfDay 21 3 0,"three past nine in the evening")
  , (TimeOfDay 21 4 0,"four past nine in the evening")
  , (TimeOfDay 21 5 0,"five past nine in the evening")
  , (TimeOfDay 21 6 0,"six past nine in the evening")
  , (TimeOfDay 21 7 0,"seven past nine in the evening")
  , (TimeOfDay 21 8 0,"eight past nine in the evening")
  , (TimeOfDay 21 9 0,"nine past nine in the evening")
  , (TimeOfDay 21 10 0,"ten past nine in the evening")
  , (TimeOfDay 21 11 0,"eleven past nine in the evening")
  , (TimeOfDay 21 12 0,"twelve past nine in the evening")
  , (TimeOfDay 21 13 0,"thirteen past nine in the evening")
  , (TimeOfDay 21 14 0,"fourteen past nine in the evening")
  , (TimeOfDay 21 15 0,"quarter past nine in the evening")
  , (TimeOfDay 21 16 0,"sixteen past nine in the evening")
  , (TimeOfDay 21 17 0,"seventeen past nine in the evening")
  , (TimeOfDay 21 18 0,"eighteen past nine in the evening")
  , (TimeOfDay 21 19 0,"nineteen past nine in the evening")
  , (TimeOfDay 21 20 0,"twenty past nine in the evening")
  , (TimeOfDay 21 21 0,"twenty-one past nine in the evening")
  , (TimeOfDay 21 22 0,"twenty-two past nine in the evening")
  , (TimeOfDay 21 23 0,"twenty-three past nine in the evening")
  , (TimeOfDay 21 24 0,"twenty-four past nine in the evening")
  , (TimeOfDay 21 25 0,"twenty-five past nine in the evening")
  , (TimeOfDay 21 26 0,"twenty-six past nine in the evening")
  , (TimeOfDay 21 27 0,"twenty-seven past nine in the evening")
  , (TimeOfDay 21 28 0,"twenty-eight past nine in the evening")
  , (TimeOfDay 21 29 0,"twenty-nine past nine in the evening")
  , (TimeOfDay 21 30 0,"half past nine in the evening")
  , (TimeOfDay 21 31 0,"twenty-nine to ten in the evening")
  , (TimeOfDay 21 32 0,"twenty-eight to ten in the evening")
  , (TimeOfDay 21 33 0,"twenty-seven to ten in the evening")
  , (TimeOfDay 21 34 0,"twenty-six to ten in the evening")
  , (TimeOfDay 21 35 0,"twenty-five to ten in the evening")
  , (TimeOfDay 21 36 0,"twenty-four to ten in the evening")
  , (TimeOfDay 21 37 0,"twenty-three to ten in the evening")
  , (TimeOfDay 21 38 0,"twenty-two to ten in the evening")
  , (TimeOfDay 21 39 0,"twenty-one to ten in the evening")
  , (TimeOfDay 21 40 0,"twenty to ten in the evening")
  , (TimeOfDay 21 41 0,"nineteen to ten in the evening")
  , (TimeOfDay 21 42 0,"eighteen to ten in the evening")
  , (TimeOfDay 21 43 0,"seventeen to ten in the evening")
  , (TimeOfDay 21 44 0,"sixteen to ten in the evening")
  , (TimeOfDay 21 45 0,"quarter to ten in the evening")
  , (TimeOfDay 21 46 0,"fourteen to ten in the evening")
  , (TimeOfDay 21 47 0,"thirteen to ten in the evening")
  , (TimeOfDay 21 48 0,"twelve to ten in the evening")
  , (TimeOfDay 21 49 0,"eleven to ten in the evening")
  , (TimeOfDay 21 50 0,"ten to ten in the evening")
  , (TimeOfDay 21 51 0,"nine to ten in the evening")
  , (TimeOfDay 21 52 0,"eight to ten in the evening")
  , (TimeOfDay 21 53 0,"seven to ten in the evening")
  , (TimeOfDay 21 54 0,"six to ten in the evening")
  , (TimeOfDay 21 55 0,"five to ten in the evening")
  , (TimeOfDay 21 56 0,"four to ten in the evening")
  , (TimeOfDay 21 57 0,"three to ten in the evening")
  , (TimeOfDay 21 58 0,"two to ten in the evening")
  , (TimeOfDay 21 59 0,"one to ten in the evening")
  , (TimeOfDay 22 0 0,"ten o'clock in the evening")
  , (TimeOfDay 22 1 0,"one past ten in the evening")
  , (TimeOfDay 22 2 0,"two past ten in the evening")
  , (TimeOfDay 22 3 0,"three past ten in the evening")
  , (TimeOfDay 22 4 0,"four past ten in the evening")
  , (TimeOfDay 22 5 0,"five past ten in the evening")
  , (TimeOfDay 22 6 0,"six past ten in the evening")
  , (TimeOfDay 22 7 0,"seven past ten in the evening")
  , (TimeOfDay 22 8 0,"eight past ten in the evening")
  , (TimeOfDay 22 9 0,"nine past ten in the evening")
  , (TimeOfDay 22 10 0,"ten past ten in the evening")
  , (TimeOfDay 22 11 0,"eleven past ten in the evening")
  , (TimeOfDay 22 12 0,"twelve past ten in the evening")
  , (TimeOfDay 22 13 0,"thirteen past ten in the evening")
  , (TimeOfDay 22 14 0,"fourteen past ten in the evening")
  , (TimeOfDay 22 15 0,"quarter past ten in the evening")
  , (TimeOfDay 22 16 0,"sixteen past ten in the evening")
  , (TimeOfDay 22 17 0,"seventeen past ten in the evening")
  , (TimeOfDay 22 18 0,"eighteen past ten in the evening")
  , (TimeOfDay 22 19 0,"nineteen past ten in the evening")
  , (TimeOfDay 22 20 0,"twenty past ten in the evening")
  , (TimeOfDay 22 21 0,"twenty-one past ten in the evening")
  , (TimeOfDay 22 22 0,"twenty-two past ten in the evening")
  , (TimeOfDay 22 23 0,"twenty-three past ten in the evening")
  , (TimeOfDay 22 24 0,"twenty-four past ten in the evening")
  , (TimeOfDay 22 25 0,"twenty-five past ten in the evening")
  , (TimeOfDay 22 26 0,"twenty-six past ten in the evening")
  , (TimeOfDay 22 27 0,"twenty-seven past ten in the evening")
  , (TimeOfDay 22 28 0,"twenty-eight past ten in the evening")
  , (TimeOfDay 22 29 0,"twenty-nine past ten in the evening")
  , (TimeOfDay 22 30 0,"half past ten in the evening")
  , (TimeOfDay 22 31 0,"twenty-nine to eleven in the evening")
  , (TimeOfDay 22 32 0,"twenty-eight to eleven in the evening")
  , (TimeOfDay 22 33 0,"twenty-seven to eleven in the evening")
  , (TimeOfDay 22 34 0,"twenty-six to eleven in the evening")
  , (TimeOfDay 22 35 0,"twenty-five to eleven in the evening")
  , (TimeOfDay 22 36 0,"twenty-four to eleven in the evening")
  , (TimeOfDay 22 37 0,"twenty-three to eleven in the evening")
  , (TimeOfDay 22 38 0,"twenty-two to eleven in the evening")
  , (TimeOfDay 22 39 0,"twenty-one to eleven in the evening")
  , (TimeOfDay 22 40 0,"twenty to eleven in the evening")
  , (TimeOfDay 22 41 0,"nineteen to eleven in the evening")
  , (TimeOfDay 22 42 0,"eighteen to eleven in the evening")
  , (TimeOfDay 22 43 0,"seventeen to eleven in the evening")
  , (TimeOfDay 22 44 0,"sixteen to eleven in the evening")
  , (TimeOfDay 22 45 0,"quarter to eleven in the evening")
  , (TimeOfDay 22 46 0,"fourteen to eleven in the evening")
  , (TimeOfDay 22 47 0,"thirteen to eleven in the evening")
  , (TimeOfDay 22 48 0,"twelve to eleven in the evening")
  , (TimeOfDay 22 49 0,"eleven to eleven in the evening")
  , (TimeOfDay 22 50 0,"ten to eleven in the evening")
  , (TimeOfDay 22 51 0,"nine to eleven in the evening")
  , (TimeOfDay 22 52 0,"eight to eleven in the evening")
  , (TimeOfDay 22 53 0,"seven to eleven in the evening")
  , (TimeOfDay 22 54 0,"six to eleven in the evening")
  , (TimeOfDay 22 55 0,"five to eleven in the evening")
  , (TimeOfDay 22 56 0,"four to eleven in the evening")
  , (TimeOfDay 22 57 0,"three to eleven in the evening")
  , (TimeOfDay 22 58 0,"two to eleven in the evening")
  , (TimeOfDay 22 59 0,"one to eleven in the evening")
  , (TimeOfDay 23 0 0,"eleven o'clock in the evening")
  , (TimeOfDay 23 1 0,"one past eleven in the evening")
  , (TimeOfDay 23 2 0,"two past eleven in the evening")
  , (TimeOfDay 23 3 0,"three past eleven in the evening")
  , (TimeOfDay 23 4 0,"four past eleven in the evening")
  , (TimeOfDay 23 5 0,"five past eleven in the evening")
  , (TimeOfDay 23 6 0,"six past eleven in the evening")
  , (TimeOfDay 23 7 0,"seven past eleven in the evening")
  , (TimeOfDay 23 8 0,"eight past eleven in the evening")
  , (TimeOfDay 23 9 0,"nine past eleven in the evening")
  , (TimeOfDay 23 10 0,"ten past eleven in the evening")
  , (TimeOfDay 23 11 0,"eleven past eleven in the evening")
  , (TimeOfDay 23 12 0,"twelve past eleven in the evening")
  , (TimeOfDay 23 13 0,"thirteen past eleven in the evening")
  , (TimeOfDay 23 14 0,"fourteen past eleven in the evening")
  , (TimeOfDay 23 15 0,"quarter past eleven in the evening")
  , (TimeOfDay 23 16 0,"sixteen past eleven in the evening")
  , (TimeOfDay 23 17 0,"seventeen past eleven in the evening")
  , (TimeOfDay 23 18 0,"eighteen past eleven in the evening")
  , (TimeOfDay 23 19 0,"nineteen past eleven in the evening")
  , (TimeOfDay 23 20 0,"twenty past eleven in the evening")
  , (TimeOfDay 23 21 0,"twenty-one past eleven in the evening")
  , (TimeOfDay 23 22 0,"twenty-two past eleven in the evening")
  , (TimeOfDay 23 23 0,"twenty-three past eleven in the evening")
  , (TimeOfDay 23 24 0,"twenty-four past eleven in the evening")
  , (TimeOfDay 23 25 0,"twenty-five past eleven in the evening")
  , (TimeOfDay 23 26 0,"twenty-six past eleven in the evening")
  , (TimeOfDay 23 27 0,"twenty-seven past eleven in the evening")
  , (TimeOfDay 23 28 0,"twenty-eight past eleven in the evening")
  , (TimeOfDay 23 29 0,"twenty-nine past eleven in the evening")
  , (TimeOfDay 23 30 0,"half past eleven in the evening")
  , (TimeOfDay 23 31 0,"twenty-nine to twelve in the evening")
  , (TimeOfDay 23 32 0,"twenty-eight to twelve in the evening")
  , (TimeOfDay 23 33 0,"twenty-seven to twelve in the evening")
  , (TimeOfDay 23 34 0,"twenty-six to twelve in the evening")
  , (TimeOfDay 23 35 0,"twenty-five to twelve in the evening")
  , (TimeOfDay 23 36 0,"twenty-four to twelve in the evening")
  , (TimeOfDay 23 37 0,"twenty-three to twelve in the evening")
  , (TimeOfDay 23 38 0,"twenty-two to twelve in the evening")
  , (TimeOfDay 23 39 0,"twenty-one to twelve in the evening")
  , (TimeOfDay 23 40 0,"twenty to twelve in the evening")
  , (TimeOfDay 23 41 0,"nineteen to twelve in the evening")
  , (TimeOfDay 23 42 0,"eighteen to twelve in the evening")
  , (TimeOfDay 23 43 0,"seventeen to twelve in the evening")
  , (TimeOfDay 23 44 0,"sixteen to twelve in the evening")
  , (TimeOfDay 23 45 0,"quarter to twelve in the evening")
  , (TimeOfDay 23 46 0,"fourteen to twelve in the evening")
  , (TimeOfDay 23 47 0,"thirteen to twelve in the evening")
  , (TimeOfDay 23 48 0,"twelve to twelve in the evening")
  , (TimeOfDay 23 49 0,"eleven to twelve in the evening")
  , (TimeOfDay 23 50 0,"ten to twelve in the evening")
  , (TimeOfDay 23 51 0,"nine to twelve in the evening")
  , (TimeOfDay 23 52 0,"eight to twelve in the evening")
  , (TimeOfDay 23 53 0,"seven to twelve in the evening")
  , (TimeOfDay 23 54 0,"six to twelve in the evening")
  , (TimeOfDay 23 55 0,"five to twelve in the evening")
  , (TimeOfDay 23 56 0,"four to twelve in the evening")
  , (TimeOfDay 23 57 0,"three to twelve in the evening")
  , (TimeOfDay 23 58 0,"two to twelve in the evening")
  , (TimeOfDay 23 59 0,"one to twelve in the evening")
  ]
